# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class IdentityPoolRoleAttachment(pulumi.CustomResource):
    identity_pool_id: pulumi.Output[str]
    """
    An identity pool ID in the format REGION:GUID.
    """
    role_mappings: pulumi.Output[list]
    """
    A List of Role Mapping.

      * `ambiguousRoleResolution` (`str`) - Specifies the action to be taken if either no rules match the claim value for the Rules type, or there is no cognito:preferred_role claim and there are multiple cognito:roles matches for the Token type. `Required` if you specify Token or Rules as the Type.
      * `identity_provider` (`str`) - A string identifying the identity provider, for example, "graph.facebook.com" or "cognito-idp.us-east-1.amazonaws.com/us-east-1_abcdefghi:app_client_id".
      * `mappingRules` (`list`) - The Rules Configuration to be used for mapping users to roles. You can specify up to 25 rules per identity provider. Rules are evaluated in order. The first one to match specifies the role.
        * `claim` (`str`) - The claim name that must be present in the token, for example, "isAdmin" or "paid".
        * `matchType` (`str`) - The match condition that specifies how closely the claim value in the IdP token must match Value.
        * `role_arn` (`str`) - The role ARN.
        * `value` (`str`) - A brief string that the claim must match, for example, "paid" or "yes".

      * `type` (`str`) - The role mapping type.
    """
    roles: pulumi.Output[dict]
    """
    The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.
    """
    def __init__(__self__, resource_name, opts=None, identity_pool_id=None, role_mappings=None, roles=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an AWS Cognito Identity Pool Roles Attachment.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        main_identity_pool = aws.cognito.IdentityPool("mainIdentityPool",
            allow_unauthenticated_identities=False,
            identity_pool_name="identity pool",
            supported_login_providers={
                "graph.facebook.com": "7346241598935555",
            })
        authenticated_role = aws.iam.Role("authenticatedRole", assume_role_policy=main_identity_pool.id.apply(lambda id: f\"\"\"{{
          "Version": "2012-10-17",
          "Statement": [
            {{
              "Effect": "Allow",
              "Principal": {{
                "Federated": "cognito-identity.amazonaws.com"
              }},
              "Action": "sts:AssumeRoleWithWebIdentity",
              "Condition": {{
                "StringEquals": {{
                  "cognito-identity.amazonaws.com:aud": "{id}"
                }},
                "ForAnyValue:StringLike": {{
                  "cognito-identity.amazonaws.com:amr": "authenticated"
                }}
              }}
            }}
          ]
        }}

        \"\"\"))
        authenticated_role_policy = aws.iam.RolePolicy("authenticatedRolePolicy",
            policy=\"\"\"{
          "Version": "2012-10-17",
          "Statement": [
            {
              "Effect": "Allow",
              "Action": [
                "mobileanalytics:PutEvents",
                "cognito-sync:*",
                "cognito-identity:*"
              ],
              "Resource": [
                "*"
              ]
            }
          ]
        }

        \"\"\",
            role=authenticated_role.id)
        main_identity_pool_role_attachment = aws.cognito.IdentityPoolRoleAttachment("mainIdentityPoolRoleAttachment",
            identity_pool_id=main_identity_pool.id,
            role_mappings=[{
                "ambiguousRoleResolution": "AuthenticatedRole",
                "identityProvider": "graph.facebook.com",
                "mappingRule": [{
                    "claim": "isAdmin",
                    "matchType": "Equals",
                    "roleArn": authenticated_role.arn,
                    "value": "paid",
                }],
                "type": "Rules",
            }],
            roles={
                "authenticated": authenticated_role.arn,
            })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] identity_pool_id: An identity pool ID in the format REGION:GUID.
        :param pulumi.Input[list] role_mappings: A List of Role Mapping.
        :param pulumi.Input[dict] roles: The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.

        The **role_mappings** object supports the following:

          * `ambiguousRoleResolution` (`pulumi.Input[str]`) - Specifies the action to be taken if either no rules match the claim value for the Rules type, or there is no cognito:preferred_role claim and there are multiple cognito:roles matches for the Token type. `Required` if you specify Token or Rules as the Type.
          * `identity_provider` (`pulumi.Input[str]`) - A string identifying the identity provider, for example, "graph.facebook.com" or "cognito-idp.us-east-1.amazonaws.com/us-east-1_abcdefghi:app_client_id".
          * `mappingRules` (`pulumi.Input[list]`) - The Rules Configuration to be used for mapping users to roles. You can specify up to 25 rules per identity provider. Rules are evaluated in order. The first one to match specifies the role.
            * `claim` (`pulumi.Input[str]`) - The claim name that must be present in the token, for example, "isAdmin" or "paid".
            * `matchType` (`pulumi.Input[str]`) - The match condition that specifies how closely the claim value in the IdP token must match Value.
            * `role_arn` (`pulumi.Input[str]`) - The role ARN.
            * `value` (`pulumi.Input[str]`) - A brief string that the claim must match, for example, "paid" or "yes".

          * `type` (`pulumi.Input[str]`) - The role mapping type.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if identity_pool_id is None:
                raise TypeError("Missing required property 'identity_pool_id'")
            __props__['identity_pool_id'] = identity_pool_id
            __props__['role_mappings'] = role_mappings
            if roles is None:
                raise TypeError("Missing required property 'roles'")
            __props__['roles'] = roles
        super(IdentityPoolRoleAttachment, __self__).__init__(
            'aws:cognito/identityPoolRoleAttachment:IdentityPoolRoleAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, identity_pool_id=None, role_mappings=None, roles=None):
        """
        Get an existing IdentityPoolRoleAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] identity_pool_id: An identity pool ID in the format REGION:GUID.
        :param pulumi.Input[list] role_mappings: A List of Role Mapping.
        :param pulumi.Input[dict] roles: The map of roles associated with this pool. For a given role, the key will be either "authenticated" or "unauthenticated" and the value will be the Role ARN.

        The **role_mappings** object supports the following:

          * `ambiguousRoleResolution` (`pulumi.Input[str]`) - Specifies the action to be taken if either no rules match the claim value for the Rules type, or there is no cognito:preferred_role claim and there are multiple cognito:roles matches for the Token type. `Required` if you specify Token or Rules as the Type.
          * `identity_provider` (`pulumi.Input[str]`) - A string identifying the identity provider, for example, "graph.facebook.com" or "cognito-idp.us-east-1.amazonaws.com/us-east-1_abcdefghi:app_client_id".
          * `mappingRules` (`pulumi.Input[list]`) - The Rules Configuration to be used for mapping users to roles. You can specify up to 25 rules per identity provider. Rules are evaluated in order. The first one to match specifies the role.
            * `claim` (`pulumi.Input[str]`) - The claim name that must be present in the token, for example, "isAdmin" or "paid".
            * `matchType` (`pulumi.Input[str]`) - The match condition that specifies how closely the claim value in the IdP token must match Value.
            * `role_arn` (`pulumi.Input[str]`) - The role ARN.
            * `value` (`pulumi.Input[str]`) - A brief string that the claim must match, for example, "paid" or "yes".

          * `type` (`pulumi.Input[str]`) - The role mapping type.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["identity_pool_id"] = identity_pool_id
        __props__["role_mappings"] = role_mappings
        __props__["roles"] = roles
        return IdentityPoolRoleAttachment(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SecurityConfiguration(pulumi.CustomResource):
    encryption_configuration: pulumi.Output[dict]
    """
    Configuration block containing encryption configuration. Detailed below.

      * `cloudwatchEncryption` (`dict`)
        * `cloudwatchEncryptionMode` (`str`) - Encryption mode to use for CloudWatch data. Valid values: `DISABLED`, `SSE-KMS`. Default value: `DISABLED`.
        * `kms_key_arn` (`str`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

      * `jobBookmarksEncryption` (`dict`)
        * `jobBookmarksEncryptionMode` (`str`) - Encryption mode to use for job bookmarks data. Valid values: `CSE-KMS`, `DISABLED`. Default value: `DISABLED`.
        * `kms_key_arn` (`str`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

      * `s3Encryption` (`dict`) - A `s3_encryption ` block as described below, which contains encryption configuration for S3 data.
        * `kms_key_arn` (`str`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
        * `s3EncryptionMode` (`str`) - Encryption mode to use for S3 data. Valid values: `DISABLED`, `SSE-KMS`, `SSE-S3`. Default value: `DISABLED`.
    """
    name: pulumi.Output[str]
    """
    Name of the security configuration.
    """
    def __init__(__self__, resource_name, opts=None, encryption_configuration=None, name=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Glue Security Configuration.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.SecurityConfiguration("example", encryption_configuration={
            "cloudwatchEncryption": {
                "cloudwatchEncryptionMode": "DISABLED",
            },
            "jobBookmarksEncryption": {
                "jobBookmarksEncryptionMode": "DISABLED",
            },
            "s3Encryption": {
                "kmsKeyArn": data["kms.Key"]["example"]["arn"],
                "s3EncryptionMode": "SSE-KMS",
            },
        })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] encryption_configuration: Configuration block containing encryption configuration. Detailed below.
        :param pulumi.Input[str] name: Name of the security configuration.

        The **encryption_configuration** object supports the following:

          * `cloudwatchEncryption` (`pulumi.Input[dict]`)
            * `cloudwatchEncryptionMode` (`pulumi.Input[str]`) - Encryption mode to use for CloudWatch data. Valid values: `DISABLED`, `SSE-KMS`. Default value: `DISABLED`.
            * `kms_key_arn` (`pulumi.Input[str]`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

          * `jobBookmarksEncryption` (`pulumi.Input[dict]`)
            * `jobBookmarksEncryptionMode` (`pulumi.Input[str]`) - Encryption mode to use for job bookmarks data. Valid values: `CSE-KMS`, `DISABLED`. Default value: `DISABLED`.
            * `kms_key_arn` (`pulumi.Input[str]`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

          * `s3Encryption` (`pulumi.Input[dict]`) - A `s3_encryption ` block as described below, which contains encryption configuration for S3 data.
            * `kms_key_arn` (`pulumi.Input[str]`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
            * `s3EncryptionMode` (`pulumi.Input[str]`) - Encryption mode to use for S3 data. Valid values: `DISABLED`, `SSE-KMS`, `SSE-S3`. Default value: `DISABLED`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if encryption_configuration is None:
                raise TypeError("Missing required property 'encryption_configuration'")
            __props__['encryption_configuration'] = encryption_configuration
            __props__['name'] = name
        super(SecurityConfiguration, __self__).__init__(
            'aws:glue/securityConfiguration:SecurityConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, encryption_configuration=None, name=None):
        """
        Get an existing SecurityConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] encryption_configuration: Configuration block containing encryption configuration. Detailed below.
        :param pulumi.Input[str] name: Name of the security configuration.

        The **encryption_configuration** object supports the following:

          * `cloudwatchEncryption` (`pulumi.Input[dict]`)
            * `cloudwatchEncryptionMode` (`pulumi.Input[str]`) - Encryption mode to use for CloudWatch data. Valid values: `DISABLED`, `SSE-KMS`. Default value: `DISABLED`.
            * `kms_key_arn` (`pulumi.Input[str]`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

          * `jobBookmarksEncryption` (`pulumi.Input[dict]`)
            * `jobBookmarksEncryptionMode` (`pulumi.Input[str]`) - Encryption mode to use for job bookmarks data. Valid values: `CSE-KMS`, `DISABLED`. Default value: `DISABLED`.
            * `kms_key_arn` (`pulumi.Input[str]`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

          * `s3Encryption` (`pulumi.Input[dict]`) - A `s3_encryption ` block as described below, which contains encryption configuration for S3 data.
            * `kms_key_arn` (`pulumi.Input[str]`) - Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
            * `s3EncryptionMode` (`pulumi.Input[str]`) - Encryption mode to use for S3 data. Valid values: `DISABLED`, `SSE-KMS`, `SSE-S3`. Default value: `DISABLED`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["encryption_configuration"] = encryption_configuration
        __props__["name"] = name
        return SecurityConfiguration(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetPlanResult:
    """
    A collection of values returned by getPlan.
    """
    def __init__(__self__, arn=None, id=None, name=None, plan_id=None, tags=None, version=None):
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        __self__.arn = arn
        """
        The ARN of the backup plan.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        The display name of a backup plan.
        """
        if plan_id and not isinstance(plan_id, str):
            raise TypeError("Expected argument 'plan_id' to be a str")
        __self__.plan_id = plan_id
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        """
        Metadata that you can assign to help organize the plans you create.
        """
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        __self__.version = version
        """
        Unique, randomly generated, Unicode, UTF-8 encoded string that serves as the version ID of the backup plan.
        """
class AwaitableGetPlanResult(GetPlanResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPlanResult(
            arn=self.arn,
            id=self.id,
            name=self.name,
            plan_id=self.plan_id,
            tags=self.tags,
            version=self.version)

def get_plan(plan_id=None,tags=None,opts=None):
    """
    Use this data source to get information on an existing backup plan.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.backup.get_plan(plan_id="tf_example_backup_plan_id")
    ```



    :param str plan_id: The backup plan ID.
    :param dict tags: Metadata that you can assign to help organize the plans you create.
    """
    __args__ = dict()


    __args__['planId'] = plan_id
    __args__['tags'] = tags
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:backup/getPlan:getPlan', __args__, opts=opts).value

    return AwaitableGetPlanResult(
        arn=__ret__.get('arn'),
        id=__ret__.get('id'),
        name=__ret__.get('name'),
        plan_id=__ret__.get('planId'),
        tags=__ret__.get('tags'),
        version=__ret__.get('version'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ReceiptRule(pulumi.CustomResource):
    add_header_actions: pulumi.Output[list]
    """
    A list of Add Header Action blocks. Documented below.

      * `headerName` (`str`) - The name of the header to add
      * `headerValue` (`str`) - The value of the header to add
      * `position` (`float`) - The position of the action in the receipt rule
    """
    after: pulumi.Output[str]
    """
    The name of the rule to place this rule after
    """
    bounce_actions: pulumi.Output[list]
    """
    A list of Bounce Action blocks. Documented below.

      * `message` (`str`) - The message to send
      * `position` (`float`) - The position of the action in the receipt rule
      * `sender` (`str`) - The email address of the sender
      * `smtpReplyCode` (`str`) - The RFC 5321 SMTP reply code
      * `status_code` (`str`) - The RFC 3463 SMTP enhanced status code
      * `topic_arn` (`str`) - The ARN of an SNS topic to notify
    """
    enabled: pulumi.Output[bool]
    """
    If true, the rule will be enabled
    """
    lambda_actions: pulumi.Output[list]
    """
    A list of Lambda Action blocks. Documented below.

      * `function_arn` (`str`) - The ARN of the Lambda function to invoke
      * `invocationType` (`str`) - Event or RequestResponse
      * `position` (`float`) - The position of the action in the receipt rule
      * `topic_arn` (`str`) - The ARN of an SNS topic to notify
    """
    name: pulumi.Output[str]
    """
    The name of the rule
    """
    recipients: pulumi.Output[list]
    """
    A list of email addresses
    """
    rule_set_name: pulumi.Output[str]
    """
    The name of the rule set
    """
    s3_actions: pulumi.Output[list]
    """
    A list of S3 Action blocks. Documented below.

      * `bucket_name` (`str`) - The name of the S3 bucket
      * `kms_key_arn` (`str`) - The ARN of the KMS key
      * `objectKeyPrefix` (`str`) - The key prefix of the S3 bucket
      * `position` (`float`) - The position of the action in the receipt rule
      * `topic_arn` (`str`) - The ARN of an SNS topic to notify
    """
    scan_enabled: pulumi.Output[bool]
    """
    If true, incoming emails will be scanned for spam and viruses
    """
    sns_actions: pulumi.Output[list]
    """
    A list of SNS Action blocks. Documented below.

      * `position` (`float`) - The position of the action in the receipt rule
      * `topic_arn` (`str`) - The ARN of an SNS topic to notify
    """
    stop_actions: pulumi.Output[list]
    """
    A list of Stop Action blocks. Documented below.

      * `position` (`float`) - The position of the action in the receipt rule
      * `scope` (`str`) - The scope to apply
      * `topic_arn` (`str`) - The ARN of an SNS topic to notify
    """
    tls_policy: pulumi.Output[str]
    """
    Require or Optional
    """
    workmail_actions: pulumi.Output[list]
    """
    A list of WorkMail Action blocks. Documented below.

      * `organizationArn` (`str`) - The ARN of the WorkMail organization
      * `position` (`float`) - The position of the action in the receipt rule
      * `topic_arn` (`str`) - The ARN of an SNS topic to notify
    """
    def __init__(__self__, resource_name, opts=None, add_header_actions=None, after=None, bounce_actions=None, enabled=None, lambda_actions=None, name=None, recipients=None, rule_set_name=None, s3_actions=None, scan_enabled=None, sns_actions=None, stop_actions=None, tls_policy=None, workmail_actions=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an SES receipt rule resource

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        # Add a header to the email and store it in S3
        store = aws.ses.ReceiptRule("store",
            add_header_actions=[{
                "headerName": "Custom-Header",
                "headerValue": "Added by SES",
                "position": 1,
            }],
            enabled=True,
            recipients=["karen@example.com"],
            rule_set_name="default-rule-set",
            s3_actions=[{
                "bucketName": "emails",
                "position": 2,
            }],
            scan_enabled=True)
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] add_header_actions: A list of Add Header Action blocks. Documented below.
        :param pulumi.Input[str] after: The name of the rule to place this rule after
        :param pulumi.Input[list] bounce_actions: A list of Bounce Action blocks. Documented below.
        :param pulumi.Input[bool] enabled: If true, the rule will be enabled
        :param pulumi.Input[list] lambda_actions: A list of Lambda Action blocks. Documented below.
        :param pulumi.Input[str] name: The name of the rule
        :param pulumi.Input[list] recipients: A list of email addresses
        :param pulumi.Input[str] rule_set_name: The name of the rule set
        :param pulumi.Input[list] s3_actions: A list of S3 Action blocks. Documented below.
        :param pulumi.Input[bool] scan_enabled: If true, incoming emails will be scanned for spam and viruses
        :param pulumi.Input[list] sns_actions: A list of SNS Action blocks. Documented below.
        :param pulumi.Input[list] stop_actions: A list of Stop Action blocks. Documented below.
        :param pulumi.Input[str] tls_policy: Require or Optional
        :param pulumi.Input[list] workmail_actions: A list of WorkMail Action blocks. Documented below.

        The **add_header_actions** object supports the following:

          * `headerName` (`pulumi.Input[str]`) - The name of the header to add
          * `headerValue` (`pulumi.Input[str]`) - The value of the header to add
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule

        The **bounce_actions** object supports the following:

          * `message` (`pulumi.Input[str]`) - The message to send
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `sender` (`pulumi.Input[str]`) - The email address of the sender
          * `smtpReplyCode` (`pulumi.Input[str]`) - The RFC 5321 SMTP reply code
          * `status_code` (`pulumi.Input[str]`) - The RFC 3463 SMTP enhanced status code
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **lambda_actions** object supports the following:

          * `function_arn` (`pulumi.Input[str]`) - The ARN of the Lambda function to invoke
          * `invocationType` (`pulumi.Input[str]`) - Event or RequestResponse
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **s3_actions** object supports the following:

          * `bucket_name` (`pulumi.Input[str]`) - The name of the S3 bucket
          * `kms_key_arn` (`pulumi.Input[str]`) - The ARN of the KMS key
          * `objectKeyPrefix` (`pulumi.Input[str]`) - The key prefix of the S3 bucket
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **sns_actions** object supports the following:

          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **stop_actions** object supports the following:

          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `scope` (`pulumi.Input[str]`) - The scope to apply
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **workmail_actions** object supports the following:

          * `organizationArn` (`pulumi.Input[str]`) - The ARN of the WorkMail organization
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['add_header_actions'] = add_header_actions
            __props__['after'] = after
            __props__['bounce_actions'] = bounce_actions
            __props__['enabled'] = enabled
            __props__['lambda_actions'] = lambda_actions
            __props__['name'] = name
            __props__['recipients'] = recipients
            if rule_set_name is None:
                raise TypeError("Missing required property 'rule_set_name'")
            __props__['rule_set_name'] = rule_set_name
            __props__['s3_actions'] = s3_actions
            __props__['scan_enabled'] = scan_enabled
            __props__['sns_actions'] = sns_actions
            __props__['stop_actions'] = stop_actions
            __props__['tls_policy'] = tls_policy
            __props__['workmail_actions'] = workmail_actions
        super(ReceiptRule, __self__).__init__(
            'aws:ses/receiptRule:ReceiptRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, add_header_actions=None, after=None, bounce_actions=None, enabled=None, lambda_actions=None, name=None, recipients=None, rule_set_name=None, s3_actions=None, scan_enabled=None, sns_actions=None, stop_actions=None, tls_policy=None, workmail_actions=None):
        """
        Get an existing ReceiptRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] add_header_actions: A list of Add Header Action blocks. Documented below.
        :param pulumi.Input[str] after: The name of the rule to place this rule after
        :param pulumi.Input[list] bounce_actions: A list of Bounce Action blocks. Documented below.
        :param pulumi.Input[bool] enabled: If true, the rule will be enabled
        :param pulumi.Input[list] lambda_actions: A list of Lambda Action blocks. Documented below.
        :param pulumi.Input[str] name: The name of the rule
        :param pulumi.Input[list] recipients: A list of email addresses
        :param pulumi.Input[str] rule_set_name: The name of the rule set
        :param pulumi.Input[list] s3_actions: A list of S3 Action blocks. Documented below.
        :param pulumi.Input[bool] scan_enabled: If true, incoming emails will be scanned for spam and viruses
        :param pulumi.Input[list] sns_actions: A list of SNS Action blocks. Documented below.
        :param pulumi.Input[list] stop_actions: A list of Stop Action blocks. Documented below.
        :param pulumi.Input[str] tls_policy: Require or Optional
        :param pulumi.Input[list] workmail_actions: A list of WorkMail Action blocks. Documented below.

        The **add_header_actions** object supports the following:

          * `headerName` (`pulumi.Input[str]`) - The name of the header to add
          * `headerValue` (`pulumi.Input[str]`) - The value of the header to add
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule

        The **bounce_actions** object supports the following:

          * `message` (`pulumi.Input[str]`) - The message to send
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `sender` (`pulumi.Input[str]`) - The email address of the sender
          * `smtpReplyCode` (`pulumi.Input[str]`) - The RFC 5321 SMTP reply code
          * `status_code` (`pulumi.Input[str]`) - The RFC 3463 SMTP enhanced status code
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **lambda_actions** object supports the following:

          * `function_arn` (`pulumi.Input[str]`) - The ARN of the Lambda function to invoke
          * `invocationType` (`pulumi.Input[str]`) - Event or RequestResponse
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **s3_actions** object supports the following:

          * `bucket_name` (`pulumi.Input[str]`) - The name of the S3 bucket
          * `kms_key_arn` (`pulumi.Input[str]`) - The ARN of the KMS key
          * `objectKeyPrefix` (`pulumi.Input[str]`) - The key prefix of the S3 bucket
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **sns_actions** object supports the following:

          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **stop_actions** object supports the following:

          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `scope` (`pulumi.Input[str]`) - The scope to apply
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify

        The **workmail_actions** object supports the following:

          * `organizationArn` (`pulumi.Input[str]`) - The ARN of the WorkMail organization
          * `position` (`pulumi.Input[float]`) - The position of the action in the receipt rule
          * `topic_arn` (`pulumi.Input[str]`) - The ARN of an SNS topic to notify
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["add_header_actions"] = add_header_actions
        __props__["after"] = after
        __props__["bounce_actions"] = bounce_actions
        __props__["enabled"] = enabled
        __props__["lambda_actions"] = lambda_actions
        __props__["name"] = name
        __props__["recipients"] = recipients
        __props__["rule_set_name"] = rule_set_name
        __props__["s3_actions"] = s3_actions
        __props__["scan_enabled"] = scan_enabled
        __props__["sns_actions"] = sns_actions
        __props__["stop_actions"] = stop_actions
        __props__["tls_policy"] = tls_policy
        __props__["workmail_actions"] = workmail_actions
        return ReceiptRule(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Provider(pulumi.ProviderResource):
    def __init__(__self__, resource_name, opts=None, access_key=None, allowed_account_ids=None, assume_role=None, endpoints=None, forbidden_account_ids=None, ignore_tags=None, insecure=None, max_retries=None, profile=None, region=None, s3_force_path_style=None, secret_key=None, shared_credentials_file=None, skip_credentials_validation=None, skip_get_ec2_platforms=None, skip_metadata_api_check=None, skip_region_validation=None, skip_requesting_account_id=None, token=None, __props__=None, __name__=None, __opts__=None):
        """
        The provider type for the aws package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_key: The access key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
        :param pulumi.Input[dict] ignore_tags: Configuration block with settings to ignore resource tags across all resources.
        :param pulumi.Input[bool] insecure: Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is `false`
        :param pulumi.Input[float] max_retries: The maximum number of times an AWS API request is being executed. If the API request still fails, an error is thrown.
        :param pulumi.Input[str] profile: The profile for API operations. If not set, the default profile created with `aws configure` will be used.
        :param pulumi.Input[str] region: The region where AWS operations will take place. Examples are us-east-1, us-west-2, etc.
        :param pulumi.Input[bool] s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By
               default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY).
               Specific to the Amazon S3 service.
        :param pulumi.Input[str] secret_key: The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
        :param pulumi.Input[str] shared_credentials_file: The path to the shared credentials file. If not set this defaults to ~/.aws/credentials.
        :param pulumi.Input[bool] skip_credentials_validation: Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS
               available/implemented.
        :param pulumi.Input[bool] skip_get_ec2_platforms: Skip getting the supported EC2 platforms. Used by users that don't have ec2:DescribeAccountAttributes permissions.
        :param pulumi.Input[bool] skip_region_validation: Skip static validation of region name. Used by users of alternative AWS-like APIs or users w/ access to regions that are
               not public (yet).
        :param pulumi.Input[bool] skip_requesting_account_id: Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
        :param pulumi.Input[str] token: session token. A session token is only required if you are using temporary security credentials.

        The **assume_role** object supports the following:

          * `externalId` (`pulumi.Input[str]`)
          * `policy` (`pulumi.Input[str]`)
          * `role_arn` (`pulumi.Input[str]`)
          * `session_name` (`pulumi.Input[str]`)

        The **endpoints** object supports the following:

          * `accessanalyzer` (`pulumi.Input[str]`)
          * `acm` (`pulumi.Input[str]`)
          * `acmpca` (`pulumi.Input[str]`)
          * `amplify` (`pulumi.Input[str]`)
          * `apigateway` (`pulumi.Input[str]`)
          * `applicationautoscaling` (`pulumi.Input[str]`)
          * `applicationinsights` (`pulumi.Input[str]`)
          * `appmesh` (`pulumi.Input[str]`)
          * `appstream` (`pulumi.Input[str]`)
          * `appsync` (`pulumi.Input[str]`)
          * `athena` (`pulumi.Input[str]`)
          * `autoscaling` (`pulumi.Input[str]`)
          * `autoscalingplans` (`pulumi.Input[str]`)
          * `backup` (`pulumi.Input[str]`)
          * `batch` (`pulumi.Input[str]`)
          * `budgets` (`pulumi.Input[str]`)
          * `cloud9` (`pulumi.Input[str]`)
          * `cloudformation` (`pulumi.Input[str]`)
          * `cloudfront` (`pulumi.Input[str]`)
          * `cloudhsm` (`pulumi.Input[str]`)
          * `cloudsearch` (`pulumi.Input[str]`)
          * `cloudtrail` (`pulumi.Input[str]`)
          * `cloudwatch` (`pulumi.Input[str]`)
          * `cloudwatchevents` (`pulumi.Input[str]`)
          * `cloudwatchlogs` (`pulumi.Input[str]`)
          * `codebuild` (`pulumi.Input[str]`)
          * `codecommit` (`pulumi.Input[str]`)
          * `codedeploy` (`pulumi.Input[str]`)
          * `codepipeline` (`pulumi.Input[str]`)
          * `cognitoidentity` (`pulumi.Input[str]`)
          * `cognitoidp` (`pulumi.Input[str]`)
          * `configservice` (`pulumi.Input[str]`)
          * `cur` (`pulumi.Input[str]`)
          * `dataexchange` (`pulumi.Input[str]`)
          * `datapipeline` (`pulumi.Input[str]`)
          * `datasync` (`pulumi.Input[str]`)
          * `dax` (`pulumi.Input[str]`)
          * `devicefarm` (`pulumi.Input[str]`)
          * `directconnect` (`pulumi.Input[str]`)
          * `dlm` (`pulumi.Input[str]`)
          * `dms` (`pulumi.Input[str]`)
          * `docdb` (`pulumi.Input[str]`)
          * `ds` (`pulumi.Input[str]`)
          * `dynamodb` (`pulumi.Input[str]`)
          * `ec2` (`pulumi.Input[str]`)
          * `ecr` (`pulumi.Input[str]`)
          * `ecs` (`pulumi.Input[str]`)
          * `efs` (`pulumi.Input[str]`)
          * `eks` (`pulumi.Input[str]`)
          * `elasticache` (`pulumi.Input[str]`)
          * `elasticbeanstalk` (`pulumi.Input[str]`)
          * `elastictranscoder` (`pulumi.Input[str]`)
          * `elb` (`pulumi.Input[str]`)
          * `emr` (`pulumi.Input[str]`)
          * `es` (`pulumi.Input[str]`)
          * `firehose` (`pulumi.Input[str]`)
          * `fms` (`pulumi.Input[str]`)
          * `forecast` (`pulumi.Input[str]`)
          * `fsx` (`pulumi.Input[str]`)
          * `gamelift` (`pulumi.Input[str]`)
          * `glacier` (`pulumi.Input[str]`)
          * `globalaccelerator` (`pulumi.Input[str]`)
          * `glue` (`pulumi.Input[str]`)
          * `greengrass` (`pulumi.Input[str]`)
          * `guardduty` (`pulumi.Input[str]`)
          * `iam` (`pulumi.Input[str]`)
          * `imagebuilder` (`pulumi.Input[str]`)
          * `inspector` (`pulumi.Input[str]`)
          * `iot` (`pulumi.Input[str]`)
          * `iotanalytics` (`pulumi.Input[str]`)
          * `iotevents` (`pulumi.Input[str]`)
          * `kafka` (`pulumi.Input[str]`)
          * `kinesis` (`pulumi.Input[str]`)
          * `kinesisAnalytics` (`pulumi.Input[str]`)
          * `kinesisanalytics` (`pulumi.Input[str]`)
          * `kinesisanalyticsv2` (`pulumi.Input[str]`)
          * `kinesisvideo` (`pulumi.Input[str]`)
          * `kms` (`pulumi.Input[str]`)
          * `lakeformation` (`pulumi.Input[str]`)
          * `lambda_` (`pulumi.Input[str]`)
          * `lexmodels` (`pulumi.Input[str]`)
          * `licensemanager` (`pulumi.Input[str]`)
          * `lightsail` (`pulumi.Input[str]`)
          * `macie` (`pulumi.Input[str]`)
          * `managedblockchain` (`pulumi.Input[str]`)
          * `marketplacecatalog` (`pulumi.Input[str]`)
          * `mediaconnect` (`pulumi.Input[str]`)
          * `mediaconvert` (`pulumi.Input[str]`)
          * `medialive` (`pulumi.Input[str]`)
          * `mediapackage` (`pulumi.Input[str]`)
          * `mediastore` (`pulumi.Input[str]`)
          * `mediastoredata` (`pulumi.Input[str]`)
          * `mq` (`pulumi.Input[str]`)
          * `neptune` (`pulumi.Input[str]`)
          * `networkmanager` (`pulumi.Input[str]`)
          * `opsworks` (`pulumi.Input[str]`)
          * `organizations` (`pulumi.Input[str]`)
          * `personalize` (`pulumi.Input[str]`)
          * `pinpoint` (`pulumi.Input[str]`)
          * `pricing` (`pulumi.Input[str]`)
          * `qldb` (`pulumi.Input[str]`)
          * `quicksight` (`pulumi.Input[str]`)
          * `r53` (`pulumi.Input[str]`)
          * `ram` (`pulumi.Input[str]`)
          * `rds` (`pulumi.Input[str]`)
          * `redshift` (`pulumi.Input[str]`)
          * `resourcegroups` (`pulumi.Input[str]`)
          * `route53` (`pulumi.Input[str]`)
          * `route53domains` (`pulumi.Input[str]`)
          * `route53resolver` (`pulumi.Input[str]`)
          * `s3` (`pulumi.Input[str]`)
          * `s3control` (`pulumi.Input[str]`)
          * `sagemaker` (`pulumi.Input[str]`)
          * `sdb` (`pulumi.Input[str]`)
          * `secretsmanager` (`pulumi.Input[str]`)
          * `securityhub` (`pulumi.Input[str]`)
          * `serverlessrepo` (`pulumi.Input[str]`)
          * `servicecatalog` (`pulumi.Input[str]`)
          * `servicediscovery` (`pulumi.Input[str]`)
          * `servicequotas` (`pulumi.Input[str]`)
          * `ses` (`pulumi.Input[str]`)
          * `shield` (`pulumi.Input[str]`)
          * `sns` (`pulumi.Input[str]`)
          * `sqs` (`pulumi.Input[str]`)
          * `ssm` (`pulumi.Input[str]`)
          * `stepfunctions` (`pulumi.Input[str]`)
          * `storagegateway` (`pulumi.Input[str]`)
          * `sts` (`pulumi.Input[str]`)
          * `swf` (`pulumi.Input[str]`)
          * `synthetics` (`pulumi.Input[str]`)
          * `transfer` (`pulumi.Input[str]`)
          * `waf` (`pulumi.Input[str]`)
          * `wafregional` (`pulumi.Input[str]`)
          * `wafv2` (`pulumi.Input[str]`)
          * `worklink` (`pulumi.Input[str]`)
          * `workmail` (`pulumi.Input[str]`)
          * `workspaces` (`pulumi.Input[str]`)
          * `xray` (`pulumi.Input[str]`)

        The **ignore_tags** object supports the following:

          * `keyPrefixes` (`pulumi.Input[list]`)
          * `keys` (`pulumi.Input[list]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['access_key'] = access_key
            __props__['allowed_account_ids'] = pulumi.Output.from_input(allowed_account_ids).apply(json.dumps) if allowed_account_ids is not None else None
            __props__['assume_role'] = pulumi.Output.from_input(assume_role).apply(json.dumps) if assume_role is not None else None
            __props__['endpoints'] = pulumi.Output.from_input(endpoints).apply(json.dumps) if endpoints is not None else None
            __props__['forbidden_account_ids'] = pulumi.Output.from_input(forbidden_account_ids).apply(json.dumps) if forbidden_account_ids is not None else None
            __props__['ignore_tags'] = pulumi.Output.from_input(ignore_tags).apply(json.dumps) if ignore_tags is not None else None
            __props__['insecure'] = pulumi.Output.from_input(insecure).apply(json.dumps) if insecure is not None else None
            __props__['max_retries'] = pulumi.Output.from_input(max_retries).apply(json.dumps) if max_retries is not None else None
            if profile is None:
                profile = utilities.get_env('AWS_PROFILE')
            __props__['profile'] = profile
            if region is None:
                region = utilities.get_env('AWS_REGION', 'AWS_DEFAULT_REGION')
            __props__['region'] = region
            __props__['s3_force_path_style'] = pulumi.Output.from_input(s3_force_path_style).apply(json.dumps) if s3_force_path_style is not None else None
            __props__['secret_key'] = secret_key
            __props__['shared_credentials_file'] = shared_credentials_file
            __props__['skip_credentials_validation'] = pulumi.Output.from_input(skip_credentials_validation).apply(json.dumps) if skip_credentials_validation is not None else None
            __props__['skip_get_ec2_platforms'] = pulumi.Output.from_input(skip_get_ec2_platforms).apply(json.dumps) if skip_get_ec2_platforms is not None else None
            __props__['skip_metadata_api_check'] = pulumi.Output.from_input(skip_metadata_api_check).apply(json.dumps) if skip_metadata_api_check is not None else None
            __props__['skip_region_validation'] = pulumi.Output.from_input(skip_region_validation).apply(json.dumps) if skip_region_validation is not None else None
            __props__['skip_requesting_account_id'] = pulumi.Output.from_input(skip_requesting_account_id).apply(json.dumps) if skip_requesting_account_id is not None else None
            __props__['token'] = token
        super(Provider, __self__).__init__(
            'aws',
            resource_name,
            __props__,
            opts)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetIpSetResult:
    """
    A collection of values returned by getIpSet.
    """
    def __init__(__self__, addresses=None, arn=None, description=None, id=None, ip_address_version=None, name=None, scope=None):
        if addresses and not isinstance(addresses, list):
            raise TypeError("Expected argument 'addresses' to be a list")
        __self__.addresses = addresses
        """
        An array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation.
        """
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        __self__.arn = arn
        """
        The Amazon Resource Name (ARN) of the entity.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        The description of the set that helps with identification.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if ip_address_version and not isinstance(ip_address_version, str):
            raise TypeError("Expected argument 'ip_address_version' to be a str")
        __self__.ip_address_version = ip_address_version
        """
        The IP address version of the set.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        __self__.scope = scope
class AwaitableGetIpSetResult(GetIpSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpSetResult(
            addresses=self.addresses,
            arn=self.arn,
            description=self.description,
            id=self.id,
            ip_address_version=self.ip_address_version,
            name=self.name,
            scope=self.scope)

def get_ip_set(name=None,scope=None,opts=None):
    """
    Retrieves the summary of a WAFv2 IP Set.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.wafv2.get_ip_set(name="some-ip-set",
        scope="REGIONAL")
    ```



    :param str name: The name of the WAFv2 IP Set.
    :param str scope: Specifies whether this is for an AWS CloudFront distribution or for a regional application. Valid values are `CLOUDFRONT` or `REGIONAL`. To work with CloudFront, you must also specify the region `us-east-1` (N. Virginia) on the AWS provider.
    """
    __args__ = dict()


    __args__['name'] = name
    __args__['scope'] = scope
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:wafv2/getIpSet:getIpSet', __args__, opts=opts).value

    return AwaitableGetIpSetResult(
        addresses=__ret__.get('addresses'),
        arn=__ret__.get('arn'),
        description=__ret__.get('description'),
        id=__ret__.get('id'),
        ip_address_version=__ret__.get('ipAddressVersion'),
        name=__ret__.get('name'),
        scope=__ret__.get('scope'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetDetectorResult:
    """
    A collection of values returned by getDetector.
    """
    def __init__(__self__, finding_publishing_frequency=None, id=None, service_role_arn=None, status=None):
        if finding_publishing_frequency and not isinstance(finding_publishing_frequency, str):
            raise TypeError("Expected argument 'finding_publishing_frequency' to be a str")
        __self__.finding_publishing_frequency = finding_publishing_frequency
        """
        The frequency of notifications sent about subsequent finding occurrences.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        if service_role_arn and not isinstance(service_role_arn, str):
            raise TypeError("Expected argument 'service_role_arn' to be a str")
        __self__.service_role_arn = service_role_arn
        """
        The service-linked role that grants GuardDuty access to the resources in the AWS account.
        """
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
        """
        The current status of the detector.
        """
class AwaitableGetDetectorResult(GetDetectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDetectorResult(
            finding_publishing_frequency=self.finding_publishing_frequency,
            id=self.id,
            service_role_arn=self.service_role_arn,
            status=self.status)

def get_detector(id=None,opts=None):
    """
    Retrieve information about a GuardDuty detector.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.guardduty.get_detector()
    ```



    :param str id: The ID of the detector.
    """
    __args__ = dict()


    __args__['id'] = id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:guardduty/getDetector:getDetector', __args__, opts=opts).value

    return AwaitableGetDetectorResult(
        finding_publishing_frequency=__ret__.get('findingPublishingFrequency'),
        id=__ret__.get('id'),
        service_role_arn=__ret__.get('serviceRoleArn'),
        status=__ret__.get('status'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetVpcPeeringConnectionResult:
    """
    A collection of values returned by getVpcPeeringConnection.
    """
    def __init__(__self__, accepter=None, cidr_block=None, filters=None, id=None, owner_id=None, peer_cidr_block=None, peer_owner_id=None, peer_region=None, peer_vpc_id=None, region=None, requester=None, status=None, tags=None, vpc_id=None):
        if accepter and not isinstance(accepter, dict):
            raise TypeError("Expected argument 'accepter' to be a dict")
        __self__.accepter = accepter
        """
        A configuration block that describes [VPC Peering Connection]
        (https://docs.aws.amazon.com/vpc/latest/peering/what-is-vpc-peering.html) options set for the accepter VPC.
        """
        if cidr_block and not isinstance(cidr_block, str):
            raise TypeError("Expected argument 'cidr_block' to be a str")
        __self__.cidr_block = cidr_block
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        __self__.filters = filters
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        __self__.owner_id = owner_id
        if peer_cidr_block and not isinstance(peer_cidr_block, str):
            raise TypeError("Expected argument 'peer_cidr_block' to be a str")
        __self__.peer_cidr_block = peer_cidr_block
        if peer_owner_id and not isinstance(peer_owner_id, str):
            raise TypeError("Expected argument 'peer_owner_id' to be a str")
        __self__.peer_owner_id = peer_owner_id
        if peer_region and not isinstance(peer_region, str):
            raise TypeError("Expected argument 'peer_region' to be a str")
        __self__.peer_region = peer_region
        if peer_vpc_id and not isinstance(peer_vpc_id, str):
            raise TypeError("Expected argument 'peer_vpc_id' to be a str")
        __self__.peer_vpc_id = peer_vpc_id
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        __self__.region = region
        if requester and not isinstance(requester, dict):
            raise TypeError("Expected argument 'requester' to be a dict")
        __self__.requester = requester
        """
        A configuration block that describes [VPC Peering Connection]
        (https://docs.aws.amazon.com/vpc/latest/peering/what-is-vpc-peering.html) options set for the requester VPC.
        """
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        __self__.status = status
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        __self__.tags = tags
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        __self__.vpc_id = vpc_id
class AwaitableGetVpcPeeringConnectionResult(GetVpcPeeringConnectionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcPeeringConnectionResult(
            accepter=self.accepter,
            cidr_block=self.cidr_block,
            filters=self.filters,
            id=self.id,
            owner_id=self.owner_id,
            peer_cidr_block=self.peer_cidr_block,
            peer_owner_id=self.peer_owner_id,
            peer_region=self.peer_region,
            peer_vpc_id=self.peer_vpc_id,
            region=self.region,
            requester=self.requester,
            status=self.status,
            tags=self.tags,
            vpc_id=self.vpc_id)

def get_vpc_peering_connection(cidr_block=None,filters=None,id=None,owner_id=None,peer_cidr_block=None,peer_owner_id=None,peer_region=None,peer_vpc_id=None,region=None,status=None,tags=None,vpc_id=None,opts=None):
    """
    The VPC Peering Connection data source provides details about
    a specific VPC peering connection.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_aws as aws

    pc = aws.ec2.get_vpc_peering_connection(peer_cidr_block="10.0.1.0/22",
        vpc_id=aws_vpc["foo"]["id"])
    # Create a route table
    rt = aws.ec2.RouteTable("rt", vpc_id=aws_vpc["foo"]["id"])
    # Create a route
    route = aws.ec2.Route("route",
        destination_cidr_block=pc.peer_cidr_block,
        route_table_id=rt.id,
        vpc_peering_connection_id=pc.id)
    ```



    :param str cidr_block: The CIDR block of the requester VPC of the specific VPC Peering Connection to retrieve.
    :param list filters: Custom filter block as described below.
    :param str id: The ID of the specific VPC Peering Connection to retrieve.
    :param str owner_id: The AWS account ID of the owner of the requester VPC of the specific VPC Peering Connection to retrieve.
    :param str peer_cidr_block: The CIDR block of the accepter VPC of the specific VPC Peering Connection to retrieve.
    :param str peer_owner_id: The AWS account ID of the owner of the accepter VPC of the specific VPC Peering Connection to retrieve.
    :param str peer_region: The region of the accepter VPC of the specific VPC Peering Connection to retrieve.
    :param str peer_vpc_id: The ID of the accepter VPC of the specific VPC Peering Connection to retrieve.
    :param str region: The region of the requester VPC of the specific VPC Peering Connection to retrieve.
    :param str status: The status of the specific VPC Peering Connection to retrieve.
    :param dict tags: A map of tags, each pair of which must exactly match
           a pair on the desired VPC Peering Connection.
    :param str vpc_id: The ID of the requester VPC of the specific VPC Peering Connection to retrieve.

    The **filters** object supports the following:

      * `name` (`str`) - The name of the field to filter by, as defined by
        [the underlying AWS API](http://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcPeeringConnections.html).
      * `values` (`list`) - Set of values that are accepted for the given field.
        A VPC Peering Connection will be selected if any one of the given values matches.
    """
    __args__ = dict()


    __args__['cidrBlock'] = cidr_block
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['ownerId'] = owner_id
    __args__['peerCidrBlock'] = peer_cidr_block
    __args__['peerOwnerId'] = peer_owner_id
    __args__['peerRegion'] = peer_region
    __args__['peerVpcId'] = peer_vpc_id
    __args__['region'] = region
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcId'] = vpc_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('aws:ec2/getVpcPeeringConnection:getVpcPeeringConnection', __args__, opts=opts).value

    return AwaitableGetVpcPeeringConnectionResult(
        accepter=__ret__.get('accepter'),
        cidr_block=__ret__.get('cidrBlock'),
        filters=__ret__.get('filters'),
        id=__ret__.get('id'),
        owner_id=__ret__.get('ownerId'),
        peer_cidr_block=__ret__.get('peerCidrBlock'),
        peer_owner_id=__ret__.get('peerOwnerId'),
        peer_region=__ret__.get('peerRegion'),
        peer_vpc_id=__ret__.get('peerVpcId'),
        region=__ret__.get('region'),
        requester=__ret__.get('requester'),
        status=__ret__.get('status'),
        tags=__ret__.get('tags'),
        vpc_id=__ret__.get('vpcId'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class DomainName(pulumi.CustomResource):
    api_mapping_selection_expression: pulumi.Output[str]
    """
    The [API mapping selection expression](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-mapping-selection-expressions) for the domain name.
    """
    arn: pulumi.Output[str]
    """
    The ARN of the domain name.
    """
    domain_name: pulumi.Output[str]
    """
    The domain name.
    """
    domain_name_configuration: pulumi.Output[dict]
    """
    The domain name configuration.

      * `certificate_arn` (`str`) - The ARN of an AWS-managed certificate that will be used by the endpoint for the domain name. AWS Certificate Manager is the only supported source.
        Use the [`acm.Certificate`](https://www.terraform.io/docs/providers/aws/r/acm_certificate.html) resource to configure an ACM certificate.
      * `endpoint_type` (`str`) - The endpoint type. Valid values: `REGIONAL`.
      * `hosted_zone_id` (`str`) - The Amazon Route 53 Hosted Zone ID of the endpoint.
      * `security_policy` (`str`) - The Transport Layer Security (TLS) version of the [security policy](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-custom-domain-tls-version.html) for the domain name. Valid values: `TLS_1_2`.
      * `targetDomainName` (`str`) - The target domain name.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to assign to the domain name.
    """
    def __init__(__self__, resource_name, opts=None, domain_name=None, domain_name_configuration=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages an Amazon API Gateway Version 2 domain name.
        More information can be found in the [Amazon API Gateway Developer Guide](https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-custom-domains.html).

        > **Note:** This resource establishes ownership of and the TLS settings for
        a particular domain name. An API stage can be associated with the domain name using the `apigatewayv2.ApiMapping` resource.

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.apigatewayv2.DomainName("example",
            domain_name="ws-api.example.com",
            domain_name_configuration={
                "certificateArn": aws_acm_certificate["example"]["arn"],
                "endpointType": "REGIONAL",
                "securityPolicy": "TLS_1_2",
            })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain_name: The domain name.
        :param pulumi.Input[dict] domain_name_configuration: The domain name configuration.
        :param pulumi.Input[dict] tags: A map of tags to assign to the domain name.

        The **domain_name_configuration** object supports the following:

          * `certificate_arn` (`pulumi.Input[str]`) - The ARN of an AWS-managed certificate that will be used by the endpoint for the domain name. AWS Certificate Manager is the only supported source.
            Use the [`acm.Certificate`](https://www.terraform.io/docs/providers/aws/r/acm_certificate.html) resource to configure an ACM certificate.
          * `endpoint_type` (`pulumi.Input[str]`) - The endpoint type. Valid values: `REGIONAL`.
          * `hosted_zone_id` (`pulumi.Input[str]`) - The Amazon Route 53 Hosted Zone ID of the endpoint.
          * `security_policy` (`pulumi.Input[str]`) - The Transport Layer Security (TLS) version of the [security policy](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-custom-domain-tls-version.html) for the domain name. Valid values: `TLS_1_2`.
          * `targetDomainName` (`pulumi.Input[str]`) - The target domain name.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if domain_name is None:
                raise TypeError("Missing required property 'domain_name'")
            __props__['domain_name'] = domain_name
            if domain_name_configuration is None:
                raise TypeError("Missing required property 'domain_name_configuration'")
            __props__['domain_name_configuration'] = domain_name_configuration
            __props__['tags'] = tags
            __props__['api_mapping_selection_expression'] = None
            __props__['arn'] = None
        super(DomainName, __self__).__init__(
            'aws:apigatewayv2/domainName:DomainName',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, api_mapping_selection_expression=None, arn=None, domain_name=None, domain_name_configuration=None, tags=None):
        """
        Get an existing DomainName resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_mapping_selection_expression: The [API mapping selection expression](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-mapping-selection-expressions) for the domain name.
        :param pulumi.Input[str] arn: The ARN of the domain name.
        :param pulumi.Input[str] domain_name: The domain name.
        :param pulumi.Input[dict] domain_name_configuration: The domain name configuration.
        :param pulumi.Input[dict] tags: A map of tags to assign to the domain name.

        The **domain_name_configuration** object supports the following:

          * `certificate_arn` (`pulumi.Input[str]`) - The ARN of an AWS-managed certificate that will be used by the endpoint for the domain name. AWS Certificate Manager is the only supported source.
            Use the [`acm.Certificate`](https://www.terraform.io/docs/providers/aws/r/acm_certificate.html) resource to configure an ACM certificate.
          * `endpoint_type` (`pulumi.Input[str]`) - The endpoint type. Valid values: `REGIONAL`.
          * `hosted_zone_id` (`pulumi.Input[str]`) - The Amazon Route 53 Hosted Zone ID of the endpoint.
          * `security_policy` (`pulumi.Input[str]`) - The Transport Layer Security (TLS) version of the [security policy](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-custom-domain-tls-version.html) for the domain name. Valid values: `TLS_1_2`.
          * `targetDomainName` (`pulumi.Input[str]`) - The target domain name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["api_mapping_selection_expression"] = api_mapping_selection_expression
        __props__["arn"] = arn
        __props__["domain_name"] = domain_name
        __props__["domain_name_configuration"] = domain_name_configuration
        __props__["tags"] = tags
        return DomainName(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Project(pulumi.CustomResource):
    arn: pulumi.Output[str]
    """
    The ARN of the CodeBuild project.
    """
    artifacts: pulumi.Output[dict]
    """
    Information about the project's build output artifacts. Artifact blocks are documented below.

      * `artifactIdentifier` (`str`) - The artifact identifier. Must be the same specified inside AWS CodeBuild buildspec.
      * `encryptionDisabled` (`bool`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
      * `location` (`str`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket.
      * `name` (`str`) - The name of the project. If `type` is set to `S3`, this is the name of the output artifact object
      * `namespaceType` (`str`) - The namespace to use in storing build artifacts. If `type` is set to `S3`, then valid values for this parameter are: `BUILD_ID` or `NONE`.
      * `overrideArtifactName` (`bool`) - If set to true, a name specified in the build spec file overrides the artifact name.
      * `packaging` (`str`) - The type of build output artifact to create. If `type` is set to `S3`, valid values for this parameter are: `NONE` or `ZIP`
      * `path` (`str`) - If `type` is set to `S3`, this is the path to the output artifact
      * `type` (`str`) - The build output artifact's type. Valid values for this parameter are: `CODEPIPELINE`, `NO_ARTIFACTS` or `S3`.
    """
    badge_enabled: pulumi.Output[bool]
    """
    Generates a publicly-accessible URL for the projects build badge. Available as `badge_url` attribute when enabled.
    """
    badge_url: pulumi.Output[str]
    """
    The URL of the build badge when `badge_enabled` is enabled.
    """
    build_timeout: pulumi.Output[float]
    """
    How long in minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
    """
    cache: pulumi.Output[dict]
    """
    Information about the cache storage for the project. Cache blocks are documented below.

      * `location` (`str`) - The location where the AWS CodeBuild project stores cached resources. For type `S3` the value must be a valid S3 bucket name/prefix.
      * `modes` (`list`) - Specifies settings that AWS CodeBuild uses to store and reuse build dependencies. Valid values:  `LOCAL_SOURCE_CACHE`, `LOCAL_DOCKER_LAYER_CACHE`, and `LOCAL_CUSTOM_CACHE`
      * `type` (`str`) - The type of storage that will be used for the AWS CodeBuild project cache. Valid values: `NO_CACHE`, `LOCAL`, and `S3`. Defaults to `NO_CACHE`.
    """
    description: pulumi.Output[str]
    """
    A short description of the project.
    """
    encryption_key: pulumi.Output[str]
    """
    The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build project's build output artifacts.
    """
    environment: pulumi.Output[dict]
    """
    Information about the project's build environment. Environment blocks are documented below.

      * `certificate` (`str`) - The ARN of the S3 bucket, path prefix and object key that contains the PEM-encoded certificate.
      * `computeType` (`str`) - Information about the compute resources the build project will use. Available values for this parameter are: `BUILD_GENERAL1_SMALL`, `BUILD_GENERAL1_MEDIUM`, `BUILD_GENERAL1_LARGE` or `BUILD_GENERAL1_2XLARGE`. `BUILD_GENERAL1_SMALL` is only valid if `type` is set to `LINUX_CONTAINER`. When `type` is set to `LINUX_GPU_CONTAINER`, `compute_type` need to be `BUILD_GENERAL1_LARGE`.
      * `environmentVariables` (`list`) - A set of environment variables to make available to builds for this build project.
        * `name` (`str`) - The environment variable's name or key.
        * `type` (`str`) - The type of environment variable. Valid values: `PARAMETER_STORE`, `PLAINTEXT`.
        * `value` (`str`) - The environment variable's value.

      * `image` (`str`) - The Docker image to use for this build project. Valid values include [Docker images provided by CodeBuild](https://docs.aws.amazon.com/codebuild/latest/userguide/build-env-ref-available.html) (e.g `aws/codebuild/standard:2.0`), [Docker Hub images](https://hub.docker.com/) (e.g. `nginx:latest`), and full Docker repository URIs such as those for ECR (e.g. `137112412989.dkr.ecr.us-west-2.amazonaws.com/amazonlinux:latest`).
      * `imagePullCredentialsType` (`str`) - The type of credentials AWS CodeBuild uses to pull images in your build. Available values for this parameter are `CODEBUILD` or `SERVICE_ROLE`. When you use a cross-account or private registry image, you must use SERVICE_ROLE credentials. When you use an AWS CodeBuild curated image, you must use CODEBUILD credentials. Default to `CODEBUILD`
      * `privilegedMode` (`bool`) - If set to true, enables running the Docker daemon inside a Docker container. Defaults to `false`.
      * `registryCredential` (`dict`) - Information about credentials for access to a private Docker registry. Registry Credential config blocks are documented below.
        * `credential` (`str`) - The Amazon Resource Name (ARN) or name of credentials created using AWS Secrets Manager.
        * `credentialProvider` (`str`) - The service that created the credentials to access a private Docker registry. The valid value, SECRETS_MANAGER, is for AWS Secrets Manager.

      * `type` (`str`) - The type of build environment to use for related builds. Available values are: `LINUX_CONTAINER`, `LINUX_GPU_CONTAINER`, `WINDOWS_CONTAINER` or `ARM_CONTAINER`.
    """
    logs_config: pulumi.Output[dict]
    """
    Configuration for the builds to store log data to CloudWatch or S3.

      * `cloudwatchLogs` (`dict`) - Configuration for the builds to store logs to CloudWatch
        * `group_name` (`str`) - The group name of the logs in CloudWatch Logs.
        * `status` (`str`) - Current status of logs in S3 for a build project. Valid values: `ENABLED`, `DISABLED`. Defaults to `DISABLED`.
        * `streamName` (`str`) - The stream name of the logs in CloudWatch Logs.

      * `s3Logs` (`dict`) - Configuration for the builds to store logs to S3.
        * `encryptionDisabled` (`bool`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
        * `location` (`str`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket.
        * `status` (`str`) - Current status of logs in CloudWatch Logs for a build project. Valid values: `ENABLED`, `DISABLED`. Defaults to `ENABLED`.
    """
    name: pulumi.Output[str]
    """
    The projects name.
    """
    queued_timeout: pulumi.Output[float]
    """
    How long in minutes, from 5 to 480 (8 hours), a build is allowed to be queued before it times out. The default is 8 hours.
    """
    secondary_artifacts: pulumi.Output[list]
    """
    A set of secondary artifacts to be used inside the build. Secondary artifacts blocks are documented below.

      * `artifactIdentifier` (`str`) - The artifact identifier. Must be the same specified inside AWS CodeBuild buildspec.
      * `encryptionDisabled` (`bool`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
      * `location` (`str`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket. If `path` is not also specified, then `location` can also specify the path of the output artifact in the output bucket.
      * `name` (`str`) - The name of the project. If `type` is set to `S3`, this is the name of the output artifact object
      * `namespaceType` (`str`) - The namespace to use in storing build artifacts. If `type` is set to `S3`, then valid values for this parameter are: `BUILD_ID` or `NONE`.
      * `overrideArtifactName` (`bool`) - If set to true, a name specified in the build spec file overrides the artifact name.
      * `packaging` (`str`) - The type of build output artifact to create. If `type` is set to `S3`, valid values for this parameter are: `NONE` or `ZIP`
      * `path` (`str`) - If `type` is set to `S3`, this is the path to the output artifact
      * `type` (`str`) - The build output artifact's type. Valid values for this parameter are: `CODEPIPELINE`, `NO_ARTIFACTS` or `S3`.
    """
    secondary_sources: pulumi.Output[list]
    """
    A set of secondary sources to be used inside the build. Secondary sources blocks are documented below.

      * `auths` (`list`) - Information about the authorization settings for AWS CodeBuild to access the source code to be built. Auth blocks are documented below.
        * `resource` (`str`) - The resource value that applies to the specified authorization type.
        * `type` (`str`) - The authorization type to use. The only valid value is `OAUTH`

      * `buildspec` (`str`) - The build spec declaration to use for this build project's related builds.
      * `gitCloneDepth` (`float`) - Truncate git history to this many commits.
      * `gitSubmodulesConfig` (`dict`) - Information about the Git submodules configuration for an AWS CodeBuild build project. Git submodules config blocks are documented below. This option is only valid when the `type` is `CODECOMMIT`, `GITHUB` or `GITHUB_ENTERPRISE`.
        * `fetchSubmodules` (`bool`) - If set to true, fetches Git submodules for the AWS CodeBuild build project.

      * `insecureSsl` (`bool`) - Ignore SSL warnings when connecting to source control.
      * `location` (`str`) - The location of the source code from git or s3.
      * `reportBuildStatus` (`bool`) - Set to `true` to report the status of a build's start and finish to your source provider. This option is only valid when your source provider is `GITHUB`, `BITBUCKET`, or `GITHUB_ENTERPRISE`.
      * `sourceIdentifier` (`str`) - The source identifier. Source data will be put inside a folder named as this parameter inside AWS CodeBuild source directory
      * `type` (`str`) - The type of repository that contains the source code to be built. Valid values for this parameter are: `CODECOMMIT`, `CODEPIPELINE`, `GITHUB`, `GITHUB_ENTERPRISE`, `BITBUCKET` or `S3`.
    """
    service_role: pulumi.Output[str]
    """
    The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
    """
    source: pulumi.Output[dict]
    """
    Information about the project's input source code. Source blocks are documented below.

      * `auths` (`list`) - Information about the authorization settings for AWS CodeBuild to access the source code to be built. Auth blocks are documented below.
        * `resource` (`str`) - The resource value that applies to the specified authorization type.
        * `type` (`str`) - The authorization type to use. The only valid value is `OAUTH`

      * `buildspec` (`str`) - The build spec declaration to use for this build project's related builds. This must be set when `type` is `NO_SOURCE`.
      * `gitCloneDepth` (`float`) - Truncate git history to this many commits.
      * `gitSubmodulesConfig` (`dict`) - Information about the Git submodules configuration for an AWS CodeBuild build project. Git submodules config blocks are documented below. This option is only valid when the `type` is `CODECOMMIT`, `GITHUB` or `GITHUB_ENTERPRISE`.
        * `fetchSubmodules` (`bool`) - If set to true, fetches Git submodules for the AWS CodeBuild build project.

      * `insecureSsl` (`bool`) - Ignore SSL warnings when connecting to source control.
      * `location` (`str`) - The location of the source code from git or s3.
      * `reportBuildStatus` (`bool`) - Set to `true` to report the status of a build's start and finish to your source provider. This option is only valid when the `type` is `BITBUCKET` or `GITHUB`.
      * `type` (`str`) - The type of repository that contains the source code to be built. Valid values for this parameter are: `CODECOMMIT`, `CODEPIPELINE`, `GITHUB`, `GITHUB_ENTERPRISE`, `BITBUCKET`, `S3` or `NO_SOURCE`.
    """
    source_version: pulumi.Output[str]
    """
    A version of the build input to be built for this project. If not specified, the latest version is used.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to assign to the resource.
    """
    vpc_config: pulumi.Output[dict]
    """
    Configuration for the builds to run inside a VPC. VPC config blocks are documented below.

      * `security_group_ids` (`list`) - The security group IDs to assign to running builds.
      * `subnets` (`list`) - The subnet IDs within which to run builds.
      * `vpc_id` (`str`) - The ID of the VPC within which to run builds.
    """
    def __init__(__self__, resource_name, opts=None, artifacts=None, badge_enabled=None, build_timeout=None, cache=None, description=None, encryption_key=None, environment=None, logs_config=None, name=None, queued_timeout=None, secondary_artifacts=None, secondary_sources=None, service_role=None, source=None, source_version=None, tags=None, vpc_config=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a CodeBuild Project resource. See also the [`codebuild.Webhook` resource](https://www.terraform.io/docs/providers/aws/r/codebuild_webhook.html), which manages the webhook to the source (e.g. the "rebuild every time a code change is pushed" option in the CodeBuild web console).

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        example_bucket = aws.s3.Bucket("exampleBucket", acl="private")
        example_role = aws.iam.Role("exampleRole", assume_role_policy=\"\"\"{
          "Version": "2012-10-17",
          "Statement": [
            {
              "Effect": "Allow",
              "Principal": {
                "Service": "codebuild.amazonaws.com"
              },
              "Action": "sts:AssumeRole"
            }
          ]
        }

        \"\"\")
        example_role_policy = aws.iam.RolePolicy("exampleRolePolicy",
            policy=pulumi.Output.all(example_bucket.arn, example_bucket.arn).apply(lambda exampleBucketArn, exampleBucketArn1: f\"\"\"{{
          "Version": "2012-10-17",
          "Statement": [
            {{
              "Effect": "Allow",
              "Resource": [
                "*"
              ],
              "Action": [
                "logs:CreateLogGroup",
                "logs:CreateLogStream",
                "logs:PutLogEvents"
              ]
            }},
            {{
              "Effect": "Allow",
              "Action": [
                "ec2:CreateNetworkInterface",
                "ec2:DescribeDhcpOptions",
                "ec2:DescribeNetworkInterfaces",
                "ec2:DeleteNetworkInterface",
                "ec2:DescribeSubnets",
                "ec2:DescribeSecurityGroups",
                "ec2:DescribeVpcs"
              ],
              "Resource": "*"
            }},
            {{
              "Effect": "Allow",
              "Action": [
                "ec2:CreateNetworkInterfacePermission"
              ],
              "Resource": [
                "arn:aws:ec2:us-east-1:123456789012:network-interface/*"
              ],
              "Condition": {{
                "StringEquals": {{
                  "ec2:Subnet": [
                    "{aws_subnet["example1"]["arn"]}",
                    "{aws_subnet["example2"]["arn"]}"
                  ],
                  "ec2:AuthorizedService": "codebuild.amazonaws.com"
                }}
              }}
            }},
            {{
              "Effect": "Allow",
              "Action": [
                "s3:*"
              ],
              "Resource": [
                "{example_bucket_arn}",
                "{example_bucket_arn1}/*"
              ]
            }}
          ]
        }}

        \"\"\"),
            role=example_role.name)
        example_project = aws.codebuild.Project("exampleProject",
            artifacts={
                "type": "NO_ARTIFACTS",
            },
            build_timeout="5",
            cache={
                "location": example_bucket.bucket,
                "type": "S3",
            },
            description="test_codebuild_project",
            environment={
                "computeType": "BUILD_GENERAL1_SMALL",
                "environmentVariable": [
                    {
                        "name": "SOME_KEY1",
                        "value": "SOME_VALUE1",
                    },
                    {
                        "name": "SOME_KEY2",
                        "type": "PARAMETER_STORE",
                        "value": "SOME_VALUE2",
                    },
                ],
                "image": "aws/codebuild/standard:1.0",
                "imagePullCredentialsType": "CODEBUILD",
                "type": "LINUX_CONTAINER",
            },
            logs_config={
                "cloudwatchLogs": {
                    "groupName": "log-group",
                    "streamName": "log-stream",
                },
                "s3Logs": {
                    "location": example_bucket.id.apply(lambda id: f"{id}/build-log"),
                    "status": "ENABLED",
                },
            },
            service_role=example_role.arn,
            source={
                "gitCloneDepth": 1,
                "gitSubmodulesConfig": {
                    "fetchSubmodules": True,
                },
                "location": "https://github.com/mitchellh/packer.git",
                "type": "GITHUB",
            },
            source_version="master",
            tags={
                "Environment": "Test",
            },
            vpc_config={
                "securityGroupIds": [
                    aws_security_group["example1"]["id"],
                    aws_security_group["example2"]["id"],
                ],
                "subnets": [
                    aws_subnet["example1"]["id"],
                    aws_subnet["example2"]["id"],
                ],
                "vpcId": aws_vpc["example"]["id"],
            })
        project_with_cache = aws.codebuild.Project("project-with-cache",
            artifacts={
                "type": "NO_ARTIFACTS",
            },
            build_timeout="5",
            cache={
                "modes": [
                    "LOCAL_DOCKER_LAYER_CACHE",
                    "LOCAL_SOURCE_CACHE",
                ],
                "type": "LOCAL",
            },
            description="test_codebuild_project_cache",
            environment={
                "computeType": "BUILD_GENERAL1_SMALL",
                "environmentVariable": [{
                    "name": "SOME_KEY1",
                    "value": "SOME_VALUE1",
                }],
                "image": "aws/codebuild/standard:1.0",
                "imagePullCredentialsType": "CODEBUILD",
                "type": "LINUX_CONTAINER",
            },
            queued_timeout="5",
            service_role=example_role.arn,
            source={
                "gitCloneDepth": 1,
                "location": "https://github.com/mitchellh/packer.git",
                "type": "GITHUB",
            },
            tags={
                "Environment": "Test",
            })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] artifacts: Information about the project's build output artifacts. Artifact blocks are documented below.
        :param pulumi.Input[bool] badge_enabled: Generates a publicly-accessible URL for the projects build badge. Available as `badge_url` attribute when enabled.
        :param pulumi.Input[float] build_timeout: How long in minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
        :param pulumi.Input[dict] cache: Information about the cache storage for the project. Cache blocks are documented below.
        :param pulumi.Input[str] description: A short description of the project.
        :param pulumi.Input[str] encryption_key: The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build project's build output artifacts.
        :param pulumi.Input[dict] environment: Information about the project's build environment. Environment blocks are documented below.
        :param pulumi.Input[dict] logs_config: Configuration for the builds to store log data to CloudWatch or S3.
        :param pulumi.Input[str] name: The projects name.
        :param pulumi.Input[float] queued_timeout: How long in minutes, from 5 to 480 (8 hours), a build is allowed to be queued before it times out. The default is 8 hours.
        :param pulumi.Input[list] secondary_artifacts: A set of secondary artifacts to be used inside the build. Secondary artifacts blocks are documented below.
        :param pulumi.Input[list] secondary_sources: A set of secondary sources to be used inside the build. Secondary sources blocks are documented below.
        :param pulumi.Input[str] service_role: The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
        :param pulumi.Input[dict] source: Information about the project's input source code. Source blocks are documented below.
        :param pulumi.Input[str] source_version: A version of the build input to be built for this project. If not specified, the latest version is used.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        :param pulumi.Input[dict] vpc_config: Configuration for the builds to run inside a VPC. VPC config blocks are documented below.

        The **artifacts** object supports the following:

          * `artifactIdentifier` (`pulumi.Input[str]`) - The artifact identifier. Must be the same specified inside AWS CodeBuild buildspec.
          * `encryptionDisabled` (`pulumi.Input[bool]`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
          * `location` (`pulumi.Input[str]`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket.
          * `name` (`pulumi.Input[str]`) - The name of the project. If `type` is set to `S3`, this is the name of the output artifact object
          * `namespaceType` (`pulumi.Input[str]`) - The namespace to use in storing build artifacts. If `type` is set to `S3`, then valid values for this parameter are: `BUILD_ID` or `NONE`.
          * `overrideArtifactName` (`pulumi.Input[bool]`) - If set to true, a name specified in the build spec file overrides the artifact name.
          * `packaging` (`pulumi.Input[str]`) - The type of build output artifact to create. If `type` is set to `S3`, valid values for this parameter are: `NONE` or `ZIP`
          * `path` (`pulumi.Input[str]`) - If `type` is set to `S3`, this is the path to the output artifact
          * `type` (`pulumi.Input[str]`) - The build output artifact's type. Valid values for this parameter are: `CODEPIPELINE`, `NO_ARTIFACTS` or `S3`.

        The **cache** object supports the following:

          * `location` (`pulumi.Input[str]`) - The location where the AWS CodeBuild project stores cached resources. For type `S3` the value must be a valid S3 bucket name/prefix.
          * `modes` (`pulumi.Input[list]`) - Specifies settings that AWS CodeBuild uses to store and reuse build dependencies. Valid values:  `LOCAL_SOURCE_CACHE`, `LOCAL_DOCKER_LAYER_CACHE`, and `LOCAL_CUSTOM_CACHE`
          * `type` (`pulumi.Input[str]`) - The type of storage that will be used for the AWS CodeBuild project cache. Valid values: `NO_CACHE`, `LOCAL`, and `S3`. Defaults to `NO_CACHE`.

        The **environment** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - The ARN of the S3 bucket, path prefix and object key that contains the PEM-encoded certificate.
          * `computeType` (`pulumi.Input[str]`) - Information about the compute resources the build project will use. Available values for this parameter are: `BUILD_GENERAL1_SMALL`, `BUILD_GENERAL1_MEDIUM`, `BUILD_GENERAL1_LARGE` or `BUILD_GENERAL1_2XLARGE`. `BUILD_GENERAL1_SMALL` is only valid if `type` is set to `LINUX_CONTAINER`. When `type` is set to `LINUX_GPU_CONTAINER`, `compute_type` need to be `BUILD_GENERAL1_LARGE`.
          * `environmentVariables` (`pulumi.Input[list]`) - A set of environment variables to make available to builds for this build project.
            * `name` (`pulumi.Input[str]`) - The environment variable's name or key.
            * `type` (`pulumi.Input[str]`) - The type of environment variable. Valid values: `PARAMETER_STORE`, `PLAINTEXT`.
            * `value` (`pulumi.Input[str]`) - The environment variable's value.

          * `image` (`pulumi.Input[str]`) - The Docker image to use for this build project. Valid values include [Docker images provided by CodeBuild](https://docs.aws.amazon.com/codebuild/latest/userguide/build-env-ref-available.html) (e.g `aws/codebuild/standard:2.0`), [Docker Hub images](https://hub.docker.com/) (e.g. `nginx:latest`), and full Docker repository URIs such as those for ECR (e.g. `137112412989.dkr.ecr.us-west-2.amazonaws.com/amazonlinux:latest`).
          * `imagePullCredentialsType` (`pulumi.Input[str]`) - The type of credentials AWS CodeBuild uses to pull images in your build. Available values for this parameter are `CODEBUILD` or `SERVICE_ROLE`. When you use a cross-account or private registry image, you must use SERVICE_ROLE credentials. When you use an AWS CodeBuild curated image, you must use CODEBUILD credentials. Default to `CODEBUILD`
          * `privilegedMode` (`pulumi.Input[bool]`) - If set to true, enables running the Docker daemon inside a Docker container. Defaults to `false`.
          * `registryCredential` (`pulumi.Input[dict]`) - Information about credentials for access to a private Docker registry. Registry Credential config blocks are documented below.
            * `credential` (`pulumi.Input[str]`) - The Amazon Resource Name (ARN) or name of credentials created using AWS Secrets Manager.
            * `credentialProvider` (`pulumi.Input[str]`) - The service that created the credentials to access a private Docker registry. The valid value, SECRETS_MANAGER, is for AWS Secrets Manager.

          * `type` (`pulumi.Input[str]`) - The type of build environment to use for related builds. Available values are: `LINUX_CONTAINER`, `LINUX_GPU_CONTAINER`, `WINDOWS_CONTAINER` or `ARM_CONTAINER`.

        The **logs_config** object supports the following:

          * `cloudwatchLogs` (`pulumi.Input[dict]`) - Configuration for the builds to store logs to CloudWatch
            * `group_name` (`pulumi.Input[str]`) - The group name of the logs in CloudWatch Logs.
            * `status` (`pulumi.Input[str]`) - Current status of logs in S3 for a build project. Valid values: `ENABLED`, `DISABLED`. Defaults to `DISABLED`.
            * `streamName` (`pulumi.Input[str]`) - The stream name of the logs in CloudWatch Logs.

          * `s3Logs` (`pulumi.Input[dict]`) - Configuration for the builds to store logs to S3.
            * `encryptionDisabled` (`pulumi.Input[bool]`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
            * `location` (`pulumi.Input[str]`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket.
            * `status` (`pulumi.Input[str]`) - Current status of logs in CloudWatch Logs for a build project. Valid values: `ENABLED`, `DISABLED`. Defaults to `ENABLED`.

        The **secondary_artifacts** object supports the following:

          * `artifactIdentifier` (`pulumi.Input[str]`) - The artifact identifier. Must be the same specified inside AWS CodeBuild buildspec.
          * `encryptionDisabled` (`pulumi.Input[bool]`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
          * `location` (`pulumi.Input[str]`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket. If `path` is not also specified, then `location` can also specify the path of the output artifact in the output bucket.
          * `name` (`pulumi.Input[str]`) - The name of the project. If `type` is set to `S3`, this is the name of the output artifact object
          * `namespaceType` (`pulumi.Input[str]`) - The namespace to use in storing build artifacts. If `type` is set to `S3`, then valid values for this parameter are: `BUILD_ID` or `NONE`.
          * `overrideArtifactName` (`pulumi.Input[bool]`) - If set to true, a name specified in the build spec file overrides the artifact name.
          * `packaging` (`pulumi.Input[str]`) - The type of build output artifact to create. If `type` is set to `S3`, valid values for this parameter are: `NONE` or `ZIP`
          * `path` (`pulumi.Input[str]`) - If `type` is set to `S3`, this is the path to the output artifact
          * `type` (`pulumi.Input[str]`) - The build output artifact's type. Valid values for this parameter are: `CODEPIPELINE`, `NO_ARTIFACTS` or `S3`.

        The **secondary_sources** object supports the following:

          * `auths` (`pulumi.Input[list]`) - Information about the authorization settings for AWS CodeBuild to access the source code to be built. Auth blocks are documented below.
            * `resource` (`pulumi.Input[str]`) - The resource value that applies to the specified authorization type.
            * `type` (`pulumi.Input[str]`) - The authorization type to use. The only valid value is `OAUTH`

          * `buildspec` (`pulumi.Input[str]`) - The build spec declaration to use for this build project's related builds.
          * `gitCloneDepth` (`pulumi.Input[float]`) - Truncate git history to this many commits.
          * `gitSubmodulesConfig` (`pulumi.Input[dict]`) - Information about the Git submodules configuration for an AWS CodeBuild build project. Git submodules config blocks are documented below. This option is only valid when the `type` is `CODECOMMIT`, `GITHUB` or `GITHUB_ENTERPRISE`.
            * `fetchSubmodules` (`pulumi.Input[bool]`) - If set to true, fetches Git submodules for the AWS CodeBuild build project.

          * `insecureSsl` (`pulumi.Input[bool]`) - Ignore SSL warnings when connecting to source control.
          * `location` (`pulumi.Input[str]`) - The location of the source code from git or s3.
          * `reportBuildStatus` (`pulumi.Input[bool]`) - Set to `true` to report the status of a build's start and finish to your source provider. This option is only valid when your source provider is `GITHUB`, `BITBUCKET`, or `GITHUB_ENTERPRISE`.
          * `sourceIdentifier` (`pulumi.Input[str]`) - The source identifier. Source data will be put inside a folder named as this parameter inside AWS CodeBuild source directory
          * `type` (`pulumi.Input[str]`) - The type of repository that contains the source code to be built. Valid values for this parameter are: `CODECOMMIT`, `CODEPIPELINE`, `GITHUB`, `GITHUB_ENTERPRISE`, `BITBUCKET` or `S3`.

        The **source** object supports the following:

          * `auths` (`pulumi.Input[list]`) - Information about the authorization settings for AWS CodeBuild to access the source code to be built. Auth blocks are documented below.
            * `resource` (`pulumi.Input[str]`) - The resource value that applies to the specified authorization type.
            * `type` (`pulumi.Input[str]`) - The authorization type to use. The only valid value is `OAUTH`

          * `buildspec` (`pulumi.Input[str]`) - The build spec declaration to use for this build project's related builds. This must be set when `type` is `NO_SOURCE`.
          * `gitCloneDepth` (`pulumi.Input[float]`) - Truncate git history to this many commits.
          * `gitSubmodulesConfig` (`pulumi.Input[dict]`) - Information about the Git submodules configuration for an AWS CodeBuild build project. Git submodules config blocks are documented below. This option is only valid when the `type` is `CODECOMMIT`, `GITHUB` or `GITHUB_ENTERPRISE`.
            * `fetchSubmodules` (`pulumi.Input[bool]`) - If set to true, fetches Git submodules for the AWS CodeBuild build project.

          * `insecureSsl` (`pulumi.Input[bool]`) - Ignore SSL warnings when connecting to source control.
          * `location` (`pulumi.Input[str]`) - The location of the source code from git or s3.
          * `reportBuildStatus` (`pulumi.Input[bool]`) - Set to `true` to report the status of a build's start and finish to your source provider. This option is only valid when the `type` is `BITBUCKET` or `GITHUB`.
          * `type` (`pulumi.Input[str]`) - The type of repository that contains the source code to be built. Valid values for this parameter are: `CODECOMMIT`, `CODEPIPELINE`, `GITHUB`, `GITHUB_ENTERPRISE`, `BITBUCKET`, `S3` or `NO_SOURCE`.

        The **vpc_config** object supports the following:

          * `security_group_ids` (`pulumi.Input[list]`) - The security group IDs to assign to running builds.
          * `subnets` (`pulumi.Input[list]`) - The subnet IDs within which to run builds.
          * `vpc_id` (`pulumi.Input[str]`) - The ID of the VPC within which to run builds.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if artifacts is None:
                raise TypeError("Missing required property 'artifacts'")
            __props__['artifacts'] = artifacts
            __props__['badge_enabled'] = badge_enabled
            __props__['build_timeout'] = build_timeout
            __props__['cache'] = cache
            __props__['description'] = description
            __props__['encryption_key'] = encryption_key
            if environment is None:
                raise TypeError("Missing required property 'environment'")
            __props__['environment'] = environment
            __props__['logs_config'] = logs_config
            __props__['name'] = name
            __props__['queued_timeout'] = queued_timeout
            __props__['secondary_artifacts'] = secondary_artifacts
            __props__['secondary_sources'] = secondary_sources
            if service_role is None:
                raise TypeError("Missing required property 'service_role'")
            __props__['service_role'] = service_role
            if source is None:
                raise TypeError("Missing required property 'source'")
            __props__['source'] = source
            __props__['source_version'] = source_version
            __props__['tags'] = tags
            __props__['vpc_config'] = vpc_config
            __props__['arn'] = None
            __props__['badge_url'] = None
        super(Project, __self__).__init__(
            'aws:codebuild/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, artifacts=None, badge_enabled=None, badge_url=None, build_timeout=None, cache=None, description=None, encryption_key=None, environment=None, logs_config=None, name=None, queued_timeout=None, secondary_artifacts=None, secondary_sources=None, service_role=None, source=None, source_version=None, tags=None, vpc_config=None):
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The ARN of the CodeBuild project.
        :param pulumi.Input[dict] artifacts: Information about the project's build output artifacts. Artifact blocks are documented below.
        :param pulumi.Input[bool] badge_enabled: Generates a publicly-accessible URL for the projects build badge. Available as `badge_url` attribute when enabled.
        :param pulumi.Input[str] badge_url: The URL of the build badge when `badge_enabled` is enabled.
        :param pulumi.Input[float] build_timeout: How long in minutes, from 5 to 480 (8 hours), for AWS CodeBuild to wait until timing out any related build that does not get marked as completed. The default is 60 minutes.
        :param pulumi.Input[dict] cache: Information about the cache storage for the project. Cache blocks are documented below.
        :param pulumi.Input[str] description: A short description of the project.
        :param pulumi.Input[str] encryption_key: The AWS Key Management Service (AWS KMS) customer master key (CMK) to be used for encrypting the build project's build output artifacts.
        :param pulumi.Input[dict] environment: Information about the project's build environment. Environment blocks are documented below.
        :param pulumi.Input[dict] logs_config: Configuration for the builds to store log data to CloudWatch or S3.
        :param pulumi.Input[str] name: The projects name.
        :param pulumi.Input[float] queued_timeout: How long in minutes, from 5 to 480 (8 hours), a build is allowed to be queued before it times out. The default is 8 hours.
        :param pulumi.Input[list] secondary_artifacts: A set of secondary artifacts to be used inside the build. Secondary artifacts blocks are documented below.
        :param pulumi.Input[list] secondary_sources: A set of secondary sources to be used inside the build. Secondary sources blocks are documented below.
        :param pulumi.Input[str] service_role: The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that enables AWS CodeBuild to interact with dependent AWS services on behalf of the AWS account.
        :param pulumi.Input[dict] source: Information about the project's input source code. Source blocks are documented below.
        :param pulumi.Input[str] source_version: A version of the build input to be built for this project. If not specified, the latest version is used.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        :param pulumi.Input[dict] vpc_config: Configuration for the builds to run inside a VPC. VPC config blocks are documented below.

        The **artifacts** object supports the following:

          * `artifactIdentifier` (`pulumi.Input[str]`) - The artifact identifier. Must be the same specified inside AWS CodeBuild buildspec.
          * `encryptionDisabled` (`pulumi.Input[bool]`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
          * `location` (`pulumi.Input[str]`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket.
          * `name` (`pulumi.Input[str]`) - The name of the project. If `type` is set to `S3`, this is the name of the output artifact object
          * `namespaceType` (`pulumi.Input[str]`) - The namespace to use in storing build artifacts. If `type` is set to `S3`, then valid values for this parameter are: `BUILD_ID` or `NONE`.
          * `overrideArtifactName` (`pulumi.Input[bool]`) - If set to true, a name specified in the build spec file overrides the artifact name.
          * `packaging` (`pulumi.Input[str]`) - The type of build output artifact to create. If `type` is set to `S3`, valid values for this parameter are: `NONE` or `ZIP`
          * `path` (`pulumi.Input[str]`) - If `type` is set to `S3`, this is the path to the output artifact
          * `type` (`pulumi.Input[str]`) - The build output artifact's type. Valid values for this parameter are: `CODEPIPELINE`, `NO_ARTIFACTS` or `S3`.

        The **cache** object supports the following:

          * `location` (`pulumi.Input[str]`) - The location where the AWS CodeBuild project stores cached resources. For type `S3` the value must be a valid S3 bucket name/prefix.
          * `modes` (`pulumi.Input[list]`) - Specifies settings that AWS CodeBuild uses to store and reuse build dependencies. Valid values:  `LOCAL_SOURCE_CACHE`, `LOCAL_DOCKER_LAYER_CACHE`, and `LOCAL_CUSTOM_CACHE`
          * `type` (`pulumi.Input[str]`) - The type of storage that will be used for the AWS CodeBuild project cache. Valid values: `NO_CACHE`, `LOCAL`, and `S3`. Defaults to `NO_CACHE`.

        The **environment** object supports the following:

          * `certificate` (`pulumi.Input[str]`) - The ARN of the S3 bucket, path prefix and object key that contains the PEM-encoded certificate.
          * `computeType` (`pulumi.Input[str]`) - Information about the compute resources the build project will use. Available values for this parameter are: `BUILD_GENERAL1_SMALL`, `BUILD_GENERAL1_MEDIUM`, `BUILD_GENERAL1_LARGE` or `BUILD_GENERAL1_2XLARGE`. `BUILD_GENERAL1_SMALL` is only valid if `type` is set to `LINUX_CONTAINER`. When `type` is set to `LINUX_GPU_CONTAINER`, `compute_type` need to be `BUILD_GENERAL1_LARGE`.
          * `environmentVariables` (`pulumi.Input[list]`) - A set of environment variables to make available to builds for this build project.
            * `name` (`pulumi.Input[str]`) - The environment variable's name or key.
            * `type` (`pulumi.Input[str]`) - The type of environment variable. Valid values: `PARAMETER_STORE`, `PLAINTEXT`.
            * `value` (`pulumi.Input[str]`) - The environment variable's value.

          * `image` (`pulumi.Input[str]`) - The Docker image to use for this build project. Valid values include [Docker images provided by CodeBuild](https://docs.aws.amazon.com/codebuild/latest/userguide/build-env-ref-available.html) (e.g `aws/codebuild/standard:2.0`), [Docker Hub images](https://hub.docker.com/) (e.g. `nginx:latest`), and full Docker repository URIs such as those for ECR (e.g. `137112412989.dkr.ecr.us-west-2.amazonaws.com/amazonlinux:latest`).
          * `imagePullCredentialsType` (`pulumi.Input[str]`) - The type of credentials AWS CodeBuild uses to pull images in your build. Available values for this parameter are `CODEBUILD` or `SERVICE_ROLE`. When you use a cross-account or private registry image, you must use SERVICE_ROLE credentials. When you use an AWS CodeBuild curated image, you must use CODEBUILD credentials. Default to `CODEBUILD`
          * `privilegedMode` (`pulumi.Input[bool]`) - If set to true, enables running the Docker daemon inside a Docker container. Defaults to `false`.
          * `registryCredential` (`pulumi.Input[dict]`) - Information about credentials for access to a private Docker registry. Registry Credential config blocks are documented below.
            * `credential` (`pulumi.Input[str]`) - The Amazon Resource Name (ARN) or name of credentials created using AWS Secrets Manager.
            * `credentialProvider` (`pulumi.Input[str]`) - The service that created the credentials to access a private Docker registry. The valid value, SECRETS_MANAGER, is for AWS Secrets Manager.

          * `type` (`pulumi.Input[str]`) - The type of build environment to use for related builds. Available values are: `LINUX_CONTAINER`, `LINUX_GPU_CONTAINER`, `WINDOWS_CONTAINER` or `ARM_CONTAINER`.

        The **logs_config** object supports the following:

          * `cloudwatchLogs` (`pulumi.Input[dict]`) - Configuration for the builds to store logs to CloudWatch
            * `group_name` (`pulumi.Input[str]`) - The group name of the logs in CloudWatch Logs.
            * `status` (`pulumi.Input[str]`) - Current status of logs in S3 for a build project. Valid values: `ENABLED`, `DISABLED`. Defaults to `DISABLED`.
            * `streamName` (`pulumi.Input[str]`) - The stream name of the logs in CloudWatch Logs.

          * `s3Logs` (`pulumi.Input[dict]`) - Configuration for the builds to store logs to S3.
            * `encryptionDisabled` (`pulumi.Input[bool]`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
            * `location` (`pulumi.Input[str]`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket.
            * `status` (`pulumi.Input[str]`) - Current status of logs in CloudWatch Logs for a build project. Valid values: `ENABLED`, `DISABLED`. Defaults to `ENABLED`.

        The **secondary_artifacts** object supports the following:

          * `artifactIdentifier` (`pulumi.Input[str]`) - The artifact identifier. Must be the same specified inside AWS CodeBuild buildspec.
          * `encryptionDisabled` (`pulumi.Input[bool]`) - If set to true, output artifacts will not be encrypted. If `type` is set to `NO_ARTIFACTS` then this value will be ignored. Defaults to `false`.
          * `location` (`pulumi.Input[str]`) - Information about the build output artifact location. If `type` is set to `CODEPIPELINE` or `NO_ARTIFACTS` then this value will be ignored. If `type` is set to `S3`, this is the name of the output bucket. If `path` is not also specified, then `location` can also specify the path of the output artifact in the output bucket.
          * `name` (`pulumi.Input[str]`) - The name of the project. If `type` is set to `S3`, this is the name of the output artifact object
          * `namespaceType` (`pulumi.Input[str]`) - The namespace to use in storing build artifacts. If `type` is set to `S3`, then valid values for this parameter are: `BUILD_ID` or `NONE`.
          * `overrideArtifactName` (`pulumi.Input[bool]`) - If set to true, a name specified in the build spec file overrides the artifact name.
          * `packaging` (`pulumi.Input[str]`) - The type of build output artifact to create. If `type` is set to `S3`, valid values for this parameter are: `NONE` or `ZIP`
          * `path` (`pulumi.Input[str]`) - If `type` is set to `S3`, this is the path to the output artifact
          * `type` (`pulumi.Input[str]`) - The build output artifact's type. Valid values for this parameter are: `CODEPIPELINE`, `NO_ARTIFACTS` or `S3`.

        The **secondary_sources** object supports the following:

          * `auths` (`pulumi.Input[list]`) - Information about the authorization settings for AWS CodeBuild to access the source code to be built. Auth blocks are documented below.
            * `resource` (`pulumi.Input[str]`) - The resource value that applies to the specified authorization type.
            * `type` (`pulumi.Input[str]`) - The authorization type to use. The only valid value is `OAUTH`

          * `buildspec` (`pulumi.Input[str]`) - The build spec declaration to use for this build project's related builds.
          * `gitCloneDepth` (`pulumi.Input[float]`) - Truncate git history to this many commits.
          * `gitSubmodulesConfig` (`pulumi.Input[dict]`) - Information about the Git submodules configuration for an AWS CodeBuild build project. Git submodules config blocks are documented below. This option is only valid when the `type` is `CODECOMMIT`, `GITHUB` or `GITHUB_ENTERPRISE`.
            * `fetchSubmodules` (`pulumi.Input[bool]`) - If set to true, fetches Git submodules for the AWS CodeBuild build project.

          * `insecureSsl` (`pulumi.Input[bool]`) - Ignore SSL warnings when connecting to source control.
          * `location` (`pulumi.Input[str]`) - The location of the source code from git or s3.
          * `reportBuildStatus` (`pulumi.Input[bool]`) - Set to `true` to report the status of a build's start and finish to your source provider. This option is only valid when your source provider is `GITHUB`, `BITBUCKET`, or `GITHUB_ENTERPRISE`.
          * `sourceIdentifier` (`pulumi.Input[str]`) - The source identifier. Source data will be put inside a folder named as this parameter inside AWS CodeBuild source directory
          * `type` (`pulumi.Input[str]`) - The type of repository that contains the source code to be built. Valid values for this parameter are: `CODECOMMIT`, `CODEPIPELINE`, `GITHUB`, `GITHUB_ENTERPRISE`, `BITBUCKET` or `S3`.

        The **source** object supports the following:

          * `auths` (`pulumi.Input[list]`) - Information about the authorization settings for AWS CodeBuild to access the source code to be built. Auth blocks are documented below.
            * `resource` (`pulumi.Input[str]`) - The resource value that applies to the specified authorization type.
            * `type` (`pulumi.Input[str]`) - The authorization type to use. The only valid value is `OAUTH`

          * `buildspec` (`pulumi.Input[str]`) - The build spec declaration to use for this build project's related builds. This must be set when `type` is `NO_SOURCE`.
          * `gitCloneDepth` (`pulumi.Input[float]`) - Truncate git history to this many commits.
          * `gitSubmodulesConfig` (`pulumi.Input[dict]`) - Information about the Git submodules configuration for an AWS CodeBuild build project. Git submodules config blocks are documented below. This option is only valid when the `type` is `CODECOMMIT`, `GITHUB` or `GITHUB_ENTERPRISE`.
            * `fetchSubmodules` (`pulumi.Input[bool]`) - If set to true, fetches Git submodules for the AWS CodeBuild build project.

          * `insecureSsl` (`pulumi.Input[bool]`) - Ignore SSL warnings when connecting to source control.
          * `location` (`pulumi.Input[str]`) - The location of the source code from git or s3.
          * `reportBuildStatus` (`pulumi.Input[bool]`) - Set to `true` to report the status of a build's start and finish to your source provider. This option is only valid when the `type` is `BITBUCKET` or `GITHUB`.
          * `type` (`pulumi.Input[str]`) - The type of repository that contains the source code to be built. Valid values for this parameter are: `CODECOMMIT`, `CODEPIPELINE`, `GITHUB`, `GITHUB_ENTERPRISE`, `BITBUCKET`, `S3` or `NO_SOURCE`.

        The **vpc_config** object supports the following:

          * `security_group_ids` (`pulumi.Input[list]`) - The security group IDs to assign to running builds.
          * `subnets` (`pulumi.Input[list]`) - The subnet IDs within which to run builds.
          * `vpc_id` (`pulumi.Input[str]`) - The ID of the VPC within which to run builds.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["artifacts"] = artifacts
        __props__["badge_enabled"] = badge_enabled
        __props__["badge_url"] = badge_url
        __props__["build_timeout"] = build_timeout
        __props__["cache"] = cache
        __props__["description"] = description
        __props__["encryption_key"] = encryption_key
        __props__["environment"] = environment
        __props__["logs_config"] = logs_config
        __props__["name"] = name
        __props__["queued_timeout"] = queued_timeout
        __props__["secondary_artifacts"] = secondary_artifacts
        __props__["secondary_sources"] = secondary_sources
        __props__["service_role"] = service_role
        __props__["source"] = source
        __props__["source_version"] = source_version
        __props__["tags"] = tags
        __props__["vpc_config"] = vpc_config
        return Project(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Fleet(pulumi.CustomResource):
    excess_capacity_termination_policy: pulumi.Output[str]
    """
    Whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2. Valid values: `no-termination`, `termination`. Defaults to `termination`.
    """
    launch_template_config: pulumi.Output[dict]
    """
    Nested argument containing EC2 Launch Template configurations. Defined below.

      * `launchTemplateSpecification` (`dict`) - Nested argument containing EC2 Launch Template to use. Defined below.
        * `launchTemplateId` (`str`) - ID of the launch template.
        * `launchTemplateName` (`str`) - Name of the launch template.
        * `version` (`str`) - Version number of the launch template.

      * `overrides` (`list`) - Nested argument(s) containing parameters to override the same parameters in the Launch Template. Defined below.
        * `availability_zone` (`str`) - Availability Zone in which to launch the instances.
        * `instance_type` (`str`) - Instance type.
        * `maxPrice` (`str`) - Maximum price per unit hour that you are willing to pay for a Spot Instance.
        * `priority` (`float`) - Priority for the launch template override. If `on_demand_options` `allocation_strategy` is set to `prioritized`, EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. Valid values are whole numbers starting at 0.
        * `subnet_id` (`str`) - ID of the subnet in which to launch the instances.
        * `weightedCapacity` (`float`) - Number of units provided by the specified instance type.
    """
    on_demand_options: pulumi.Output[dict]
    """
    Nested argument containing On-Demand configurations. Defined below.

      * `allocation_strategy` (`str`) - How to allocate the target capacity across the Spot pools. Valid values: `diversified`, `lowestPrice`. Default: `lowestPrice`.
    """
    replace_unhealthy_instances: pulumi.Output[bool]
    """
    Whether EC2 Fleet should replace unhealthy instances. Defaults to `false`.
    """
    spot_options: pulumi.Output[dict]
    """
    Nested argument containing Spot configurations. Defined below.

      * `allocation_strategy` (`str`) - How to allocate the target capacity across the Spot pools. Valid values: `diversified`, `lowestPrice`. Default: `lowestPrice`.
      * `instanceInterruptionBehavior` (`str`) - Behavior when a Spot Instance is interrupted. Valid values: `hibernate`, `stop`, `terminate`. Default: `terminate`.
      * `instance_pools_to_use_count` (`float`) - Number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot `allocation_strategy` is set to `lowestPrice`. Default: `1`.
    """
    tags: pulumi.Output[dict]
    """
    Map of Fleet tags. To tag instances at launch, specify the tags in the Launch Template.
    """
    target_capacity_specification: pulumi.Output[dict]
    """
    Nested argument containing target capacity configurations. Defined below.

      * `defaultTargetCapacityType` (`str`) - Default target capacity type. Valid values: `on-demand`, `spot`.
      * `onDemandTargetCapacity` (`float`) - The number of On-Demand units to request.
      * `spotTargetCapacity` (`float`) - The number of Spot units to request.
      * `totalTargetCapacity` (`float`) - The number of units to request, filled using `default_target_capacity_type`.
    """
    terminate_instances: pulumi.Output[bool]
    """
    Whether to terminate instances for an EC2 Fleet if it is deleted successfully. Defaults to `false`.
    """
    terminate_instances_with_expiration: pulumi.Output[bool]
    """
    Whether running instances should be terminated when the EC2 Fleet expires. Defaults to `false`.
    """
    type: pulumi.Output[str]
    """
    The type of request. Indicates whether the EC2 Fleet only requests the target capacity, or also attempts to maintain it. Valid values: `maintain`, `request`. Defaults to `maintain`.
    """
    def __init__(__self__, resource_name, opts=None, excess_capacity_termination_policy=None, launch_template_config=None, on_demand_options=None, replace_unhealthy_instances=None, spot_options=None, tags=None, target_capacity_specification=None, terminate_instances=None, terminate_instances_with_expiration=None, type=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a resource to manage EC2 Fleets.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.ec2.Fleet("example",
            launch_template_config={
                "launchTemplateSpecification": {
                    "launchTemplateId": aws_launch_template["example"]["id"],
                    "version": aws_launch_template["example"]["latest_version"],
                },
            },
            target_capacity_specification={
                "defaultTargetCapacityType": "spot",
                "totalTargetCapacity": 5,
            })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] excess_capacity_termination_policy: Whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2. Valid values: `no-termination`, `termination`. Defaults to `termination`.
        :param pulumi.Input[dict] launch_template_config: Nested argument containing EC2 Launch Template configurations. Defined below.
        :param pulumi.Input[dict] on_demand_options: Nested argument containing On-Demand configurations. Defined below.
        :param pulumi.Input[bool] replace_unhealthy_instances: Whether EC2 Fleet should replace unhealthy instances. Defaults to `false`.
        :param pulumi.Input[dict] spot_options: Nested argument containing Spot configurations. Defined below.
        :param pulumi.Input[dict] tags: Map of Fleet tags. To tag instances at launch, specify the tags in the Launch Template.
        :param pulumi.Input[dict] target_capacity_specification: Nested argument containing target capacity configurations. Defined below.
        :param pulumi.Input[bool] terminate_instances: Whether to terminate instances for an EC2 Fleet if it is deleted successfully. Defaults to `false`.
        :param pulumi.Input[bool] terminate_instances_with_expiration: Whether running instances should be terminated when the EC2 Fleet expires. Defaults to `false`.
        :param pulumi.Input[str] type: The type of request. Indicates whether the EC2 Fleet only requests the target capacity, or also attempts to maintain it. Valid values: `maintain`, `request`. Defaults to `maintain`.

        The **launch_template_config** object supports the following:

          * `launchTemplateSpecification` (`pulumi.Input[dict]`) - Nested argument containing EC2 Launch Template to use. Defined below.
            * `launchTemplateId` (`pulumi.Input[str]`) - ID of the launch template.
            * `launchTemplateName` (`pulumi.Input[str]`) - Name of the launch template.
            * `version` (`pulumi.Input[str]`) - Version number of the launch template.

          * `overrides` (`pulumi.Input[list]`) - Nested argument(s) containing parameters to override the same parameters in the Launch Template. Defined below.
            * `availability_zone` (`pulumi.Input[str]`) - Availability Zone in which to launch the instances.
            * `instance_type` (`pulumi.Input[str]`) - Instance type.
            * `maxPrice` (`pulumi.Input[str]`) - Maximum price per unit hour that you are willing to pay for a Spot Instance.
            * `priority` (`pulumi.Input[float]`) - Priority for the launch template override. If `on_demand_options` `allocation_strategy` is set to `prioritized`, EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. Valid values are whole numbers starting at 0.
            * `subnet_id` (`pulumi.Input[str]`) - ID of the subnet in which to launch the instances.
            * `weightedCapacity` (`pulumi.Input[float]`) - Number of units provided by the specified instance type.

        The **on_demand_options** object supports the following:

          * `allocation_strategy` (`pulumi.Input[str]`) - How to allocate the target capacity across the Spot pools. Valid values: `diversified`, `lowestPrice`. Default: `lowestPrice`.

        The **spot_options** object supports the following:

          * `allocation_strategy` (`pulumi.Input[str]`) - How to allocate the target capacity across the Spot pools. Valid values: `diversified`, `lowestPrice`. Default: `lowestPrice`.
          * `instanceInterruptionBehavior` (`pulumi.Input[str]`) - Behavior when a Spot Instance is interrupted. Valid values: `hibernate`, `stop`, `terminate`. Default: `terminate`.
          * `instance_pools_to_use_count` (`pulumi.Input[float]`) - Number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot `allocation_strategy` is set to `lowestPrice`. Default: `1`.

        The **target_capacity_specification** object supports the following:

          * `defaultTargetCapacityType` (`pulumi.Input[str]`) - Default target capacity type. Valid values: `on-demand`, `spot`.
          * `onDemandTargetCapacity` (`pulumi.Input[float]`) - The number of On-Demand units to request.
          * `spotTargetCapacity` (`pulumi.Input[float]`) - The number of Spot units to request.
          * `totalTargetCapacity` (`pulumi.Input[float]`) - The number of units to request, filled using `default_target_capacity_type`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['excess_capacity_termination_policy'] = excess_capacity_termination_policy
            if launch_template_config is None:
                raise TypeError("Missing required property 'launch_template_config'")
            __props__['launch_template_config'] = launch_template_config
            __props__['on_demand_options'] = on_demand_options
            __props__['replace_unhealthy_instances'] = replace_unhealthy_instances
            __props__['spot_options'] = spot_options
            __props__['tags'] = tags
            if target_capacity_specification is None:
                raise TypeError("Missing required property 'target_capacity_specification'")
            __props__['target_capacity_specification'] = target_capacity_specification
            __props__['terminate_instances'] = terminate_instances
            __props__['terminate_instances_with_expiration'] = terminate_instances_with_expiration
            __props__['type'] = type
        super(Fleet, __self__).__init__(
            'aws:ec2/fleet:Fleet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, excess_capacity_termination_policy=None, launch_template_config=None, on_demand_options=None, replace_unhealthy_instances=None, spot_options=None, tags=None, target_capacity_specification=None, terminate_instances=None, terminate_instances_with_expiration=None, type=None):
        """
        Get an existing Fleet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] excess_capacity_termination_policy: Whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2. Valid values: `no-termination`, `termination`. Defaults to `termination`.
        :param pulumi.Input[dict] launch_template_config: Nested argument containing EC2 Launch Template configurations. Defined below.
        :param pulumi.Input[dict] on_demand_options: Nested argument containing On-Demand configurations. Defined below.
        :param pulumi.Input[bool] replace_unhealthy_instances: Whether EC2 Fleet should replace unhealthy instances. Defaults to `false`.
        :param pulumi.Input[dict] spot_options: Nested argument containing Spot configurations. Defined below.
        :param pulumi.Input[dict] tags: Map of Fleet tags. To tag instances at launch, specify the tags in the Launch Template.
        :param pulumi.Input[dict] target_capacity_specification: Nested argument containing target capacity configurations. Defined below.
        :param pulumi.Input[bool] terminate_instances: Whether to terminate instances for an EC2 Fleet if it is deleted successfully. Defaults to `false`.
        :param pulumi.Input[bool] terminate_instances_with_expiration: Whether running instances should be terminated when the EC2 Fleet expires. Defaults to `false`.
        :param pulumi.Input[str] type: The type of request. Indicates whether the EC2 Fleet only requests the target capacity, or also attempts to maintain it. Valid values: `maintain`, `request`. Defaults to `maintain`.

        The **launch_template_config** object supports the following:

          * `launchTemplateSpecification` (`pulumi.Input[dict]`) - Nested argument containing EC2 Launch Template to use. Defined below.
            * `launchTemplateId` (`pulumi.Input[str]`) - ID of the launch template.
            * `launchTemplateName` (`pulumi.Input[str]`) - Name of the launch template.
            * `version` (`pulumi.Input[str]`) - Version number of the launch template.

          * `overrides` (`pulumi.Input[list]`) - Nested argument(s) containing parameters to override the same parameters in the Launch Template. Defined below.
            * `availability_zone` (`pulumi.Input[str]`) - Availability Zone in which to launch the instances.
            * `instance_type` (`pulumi.Input[str]`) - Instance type.
            * `maxPrice` (`pulumi.Input[str]`) - Maximum price per unit hour that you are willing to pay for a Spot Instance.
            * `priority` (`pulumi.Input[float]`) - Priority for the launch template override. If `on_demand_options` `allocation_strategy` is set to `prioritized`, EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. The highest priority is launched first. The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. Valid values are whole numbers starting at 0.
            * `subnet_id` (`pulumi.Input[str]`) - ID of the subnet in which to launch the instances.
            * `weightedCapacity` (`pulumi.Input[float]`) - Number of units provided by the specified instance type.

        The **on_demand_options** object supports the following:

          * `allocation_strategy` (`pulumi.Input[str]`) - How to allocate the target capacity across the Spot pools. Valid values: `diversified`, `lowestPrice`. Default: `lowestPrice`.

        The **spot_options** object supports the following:

          * `allocation_strategy` (`pulumi.Input[str]`) - How to allocate the target capacity across the Spot pools. Valid values: `diversified`, `lowestPrice`. Default: `lowestPrice`.
          * `instanceInterruptionBehavior` (`pulumi.Input[str]`) - Behavior when a Spot Instance is interrupted. Valid values: `hibernate`, `stop`, `terminate`. Default: `terminate`.
          * `instance_pools_to_use_count` (`pulumi.Input[float]`) - Number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot `allocation_strategy` is set to `lowestPrice`. Default: `1`.

        The **target_capacity_specification** object supports the following:

          * `defaultTargetCapacityType` (`pulumi.Input[str]`) - Default target capacity type. Valid values: `on-demand`, `spot`.
          * `onDemandTargetCapacity` (`pulumi.Input[float]`) - The number of On-Demand units to request.
          * `spotTargetCapacity` (`pulumi.Input[float]`) - The number of Spot units to request.
          * `totalTargetCapacity` (`pulumi.Input[float]`) - The number of units to request, filled using `default_target_capacity_type`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["excess_capacity_termination_policy"] = excess_capacity_termination_policy
        __props__["launch_template_config"] = launch_template_config
        __props__["on_demand_options"] = on_demand_options
        __props__["replace_unhealthy_instances"] = replace_unhealthy_instances
        __props__["spot_options"] = spot_options
        __props__["tags"] = tags
        __props__["target_capacity_specification"] = target_capacity_specification
        __props__["terminate_instances"] = terminate_instances
        __props__["terminate_instances_with_expiration"] = terminate_instances_with_expiration
        __props__["type"] = type
        return Fleet(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class LogResourcePolicy(pulumi.CustomResource):
    policy_document: pulumi.Output[str]
    """
    Details of the resource policy, including the identity of the principal that is enabled to put logs to this account. This is formatted as a JSON string. Maximum length of 5120 characters.
    """
    policy_name: pulumi.Output[str]
    """
    Name of the resource policy.
    """
    def __init__(__self__, resource_name, opts=None, policy_document=None, policy_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a resource to manage a CloudWatch log resource policy.

        ## Example Usage

        ### Elasticsearch Log Publishing

        ```python
        import pulumi
        import pulumi_aws as aws

        elasticsearch_log_publishing_policy_policy_document = aws.iam.get_policy_document(statements=[{
            "actions": [
                "logs:CreateLogStream",
                "logs:PutLogEvents",
                "logs:PutLogEventsBatch",
            ],
            "principals": [{
                "identifiers": ["es.amazonaws.com"],
                "type": "Service",
            }],
            "resources": ["arn:aws:logs:*"],
        }])
        elasticsearch_log_publishing_policy_log_resource_policy = aws.cloudwatch.LogResourcePolicy("elasticsearch-log-publishing-policyLogResourcePolicy",
            policy_document=elasticsearch_log_publishing_policy_policy_document.json,
            policy_name="elasticsearch-log-publishing-policy")
        ```

        ### Route53 Query Logging

        ```python
        import pulumi
        import pulumi_aws as aws

        route53_query_logging_policy_policy_document = aws.iam.get_policy_document(statements=[{
            "actions": [
                "logs:CreateLogStream",
                "logs:PutLogEvents",
            ],
            "principals": [{
                "identifiers": ["route53.amazonaws.com"],
                "type": "Service",
            }],
            "resources": ["arn:aws:logs:*:*:log-group:/aws/route53/*"],
        }])
        route53_query_logging_policy_log_resource_policy = aws.cloudwatch.LogResourcePolicy("route53-query-logging-policyLogResourcePolicy",
            policy_document=route53_query_logging_policy_policy_document.json,
            policy_name="route53-query-logging-policy")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] policy_document: Details of the resource policy, including the identity of the principal that is enabled to put logs to this account. This is formatted as a JSON string. Maximum length of 5120 characters.
        :param pulumi.Input[str] policy_name: Name of the resource policy.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if policy_document is None:
                raise TypeError("Missing required property 'policy_document'")
            __props__['policy_document'] = policy_document
            if policy_name is None:
                raise TypeError("Missing required property 'policy_name'")
            __props__['policy_name'] = policy_name
        super(LogResourcePolicy, __self__).__init__(
            'aws:cloudwatch/logResourcePolicy:LogResourcePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, policy_document=None, policy_name=None):
        """
        Get an existing LogResourcePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] policy_document: Details of the resource policy, including the identity of the principal that is enabled to put logs to this account. This is formatted as a JSON string. Maximum length of 5120 characters.
        :param pulumi.Input[str] policy_name: Name of the resource policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["policy_document"] = policy_document
        __props__["policy_name"] = policy_name
        return LogResourcePolicy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

